/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/


#ifndef MP7JRSEXCEPTION_H
#define MP7JRSEXCEPTION_H

#include <xercesc/util/XMLString.hpp>
#include "Mp7JrsDefines.h"

typedef enum {
	MP7JRS_WARNING,
	MP7JRS_ERROR,
	MP7JRS_FATAL_ERROR
} Mp7JrsExSeverity;

/** Exception class. */
class MP7JRS_EXPORT Mp7JrsException {

public:
	Mp7JrsException(Mp7JrsExSeverity sev, const XMLCh* msg) : _severity(sev) { 
		_msg = XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(msg); 
	};

	Mp7JrsException(Mp7JrsExSeverity sev, const char* msg) : _severity(sev) { 
		_msg = XERCES_CPP_NAMESPACE_QUALIFIER XMLString::replicate(msg); 
	};
	
	/** Get severity identifier */
	Mp7JrsExSeverity GetSeverity() { return _severity; };

	/** Get the severity as string. */
	const char* GetSeverityText() {
		switch (_severity) {
		case MP7JRS_WARNING: return "Warning"; 
		case MP7JRS_ERROR: return "Error";
		case MP7JRS_FATAL_ERROR: return "Fatal error";
		default: return "";
		};
	}

	/** Get a descriptive error message. */
	const char* GetMessage() { return _msg; }

private:
	Mp7JrsExSeverity	_severity;
	char*				_msg;

};

#endif
