/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

#ifndef MP7JRSFACTORY_H
#define MP7JRSFACTORY_H

#include "MP7JRSDefines.h"

#include "Mp7JrsPtr.h"
#include "Mp7JrsPtrTypes.h"

// FTT TODO remove me #include "Mp7JrsClass.h"
#include "Mp7JrsException.h"

typedef char * SimpleGuid; // Extensible library version with real guids

class MP7JRS_EXPORT Mp7JrsLicenseException : public Mp7JrsException 
{
	public:
	Mp7JrsLicenseException(const char* msg) : Mp7JrsException(MP7JRS_ERROR,msg) {}  
};

/** Factory base class. */
class MP7JRS_EXPORT Mp7JrsFactory
{

public:
	/** @name Initialization
	 */
	//@{
	/** Initialize factory registry. */
	static void Initialize();

	/** Clean up factory registry. */
	static void Terminate();

	/** Returns the version string of the library. */
	static const char * GetVersion();
	
	//@}

	/** Map the possibly unordered type id to an ordered index. Note: this is used for registering only! */
	static unsigned int MapGuidToIndex(SimpleGuid id);

	/** Create a node object with type given as index */
	static Mp7JrsNodePtr CreateObject(unsigned int index);
	
	/** Clone the given node */
	static Mp7JrsNodePtr CloneObject(const Mp7JrsNodePtr &original);

	// Method name GetObjectType is deprecated now. Use GetTypeName instead.
	// To avoid changes in old code this define was added
#	define GetObjectType GetTypeName
	/** Get the classname associated with the given factory index. */
	static const char * GetTypeName(unsigned int index);
	
	// Method GetTypeId has been moved from Class: :Id to Factory.
	// Method name GetTypeId is deprecated now.	Use GetTypeIndex instead.
	// To minimise changes in old code this define was added
#	define GetTypeId GetTypeIndex
	static unsigned int GetTypeIndex(const XMLCh * name);

	/** Delete the given object. */
	static void DeleteObject(Mp7JrsNode * item);

	/** "Delete" the smart pointer (nothing to do) */
	template<class P>
	static void DeleteObject(Mp7JrsPtr<P> &item) {}

	/** Set if the factory must be deleted when cleaning up the factory registry */
	void SetToDelete(bool todelete) {m_ToDelete = todelete;}

	/** Get information, if factory must be deleted when factory registry is cleaned up. */
	bool GetToDelete() const {return m_ToDelete;}

protected:
	Mp7JrsFactory(SimpleGuid id, const char * classname);
	virtual ~Mp7JrsFactory(void); // Don't use delete, use DeleteFactory() instead;

	virtual void DeleteFactory();

	virtual Mp7JrsNodePtr CreateObject() = 0;
	// See note for GetObjectType above
	virtual const char * GetTypeName() const = 0;
	virtual void DeleteRawObject(Mp7JrsNode * item);

private: 
	static bool initialized;
	
	// Unimplemented methods
	Mp7JrsFactory(const Mp7JrsFactory &);

protected:
	// False, if the factory is created on stack (default)
	// Must be set to true when created on heap.
	bool m_ToDelete;

	// We must know our ordered class id for adding it to our generated nodes
	unsigned int m_ClassId;
	
};

#endif // MP7JRSFACTORY_H
