/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/


#ifndef MP7JRS_0_UNKNOWN_H
#define MP7JRS_0_UNKNOWN_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsUnknownFactory.h"
#include "Mp7JrsNode.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>
#include <xercesc/dom/DOMDocumentFragment.hpp>

/** Unknown node to wrap elements with unknown xsi:types */
class MP7JRS_EXPORT Mp7JrsUnknown :
	public Mp7JrsNode
{
	friend class Mp7JrsUnknownFactory;
public:
	// result is NOT cloned inside the GetUnknownXml func
	const XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * GetUnknownXml() const;

	// unknownxml is cloned inside the SetUnknownXml func
	void SetUnknownXml(const XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * unknownxml);

	virtual XMLCh * ToText() const{return XERCES_CPP_NAMESPACE_QUALIFIER XMLString::transcode(this->GetClassType());}
	virtual bool Parse(const XMLCh * const txt){return false;} // Intentionally unimplemented

	virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);
	virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

	virtual Mp7JrsNodeEnum GetAllChildElements() const;


protected:
	Mp7JrsUnknown();
	virtual ~Mp7JrsUnknown();
	virtual void DeepCopy(const Mp7JrsNodePtr &original);

protected:
	XERCES_CPP_NAMESPACE_QUALIFIER DOMDocumentFragment * m_DocumentFragment;
	XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * m_Document;


private:
	void Init();
	void Cleanup();

};

#endif // MP7JRS_0_UNKNOWN_H
