/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/


#ifndef MP7JRS_UTIL_H
#define MP7JRS_UTIL_H

#include "Mp7JrsDefines.h"

#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOMElement.hpp>
#include <xercesc/util/regx/match.hpp>

// check for MS GetNextSibling macro
// show custom error to avoid cryptic error message when macro has been executed
#ifdef GetNextSibling
#error Macro GetNextSibling from windowsx.h has been found, which causes error in Mp7JrsUtil code. Make sure that windowsx.h is included after Mp7JrsUtil.h .
#endif

/** Utility class */
class MP7JRS_EXPORT Mp7JrsUtil
{
public:

	/** 
	 * Use this function to avoid troubles with Xerces heap management.
	 * Since Xerces uses its own heap, you should not create a XML string
	 * like XMLCh * tmp = new XMLCh[123]; // our heap
	 * and release it with XMLString::release(tmp) // the other heap
	 * More worse, Xerces 2.2.0 doesnot provide XMLString::allocate(), so our
	 * wrapper uses XMLString::replicate to create it on the correct heap.
	 */
	static XMLCh * allocate(long length);

	static XMLCh * CatString(const XMLCh * const target, const XMLCh * const src);
	static void CatString(XMLCh ** target, const XMLCh * const src);

	static XMLCh* ConvertToXMLCh(XMLSSize_t val);

	static XMLCh * PadLeft(const XMLCh * const target, const XMLCh * const fill, const unsigned int maxlen);
	static XMLCh * PadRight(const XMLCh * const target, const XMLCh * const fill, const unsigned int maxlen);

	static XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * GetNextSibling(XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * currentnode);
	static XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * GetNextChild(XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * currentnode);
	static XMLCh * GetElementText(XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * currentnode);

	static int GetNextEndPos(XERCES_CPP_NAMESPACE_QUALIFIER Match & m, int i);

	// baw 22 04 2004 no longer needed
	//static void DeleteInDll(counter *ptr);

private:
	//Unimplemented
	Mp7JrsUtil();
	~Mp7JrsUtil();
};

#endif // MP7JRS_UTIL_H
