/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/


#ifndef _79MP7JRSANALYTICMODELTYPE_COLLECTIONTYPE_H
#define _79MP7JRSANALYTICMODELTYPE_COLLECTIONTYPE_H

// NodeRefCollectionType_H.template



#include "Mp7JrsDefines.h"
#include "Mp7JrsAnalyticModelType_CollectionTypeFactory.h"
#include "Mp7JrsNodeCollection.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>
#include "Mp7JrsValueVectorOf.h"
#include "Mp7JrsEnumerator.h"
#include "Mp7JrsFactoryDefines.h"


// no includefile for extension defined 
// file Mp7JrsAnalyticModelType_CollectionType_ExtInclude.h


class IMp7JrsAnalyticModelType_CollectionType;
typedef Mp7JrsPtr< IMp7JrsAnalyticModelType_CollectionType> Mp7JrsAnalyticModelType_CollectionPtr;

class Mp7JrsNode;
typedef Mp7JrsEnumerator< Mp7JrsPtr<Mp7JrsNode> > Mp7JrsNodeEnum;

class Mp7JrsAnalyticModelType_CollectionType;

/**
 * Generated interface IMp7JrsAnalyticModelType_CollectionType for collection Mp7JrsAnalyticModelType_CollectionType<br>
 * Located at: mds-2001.xsd, line 5657<br>
 * Item type: AnalyticModelType_LocalType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsAnalyticModelType_CollectionType :
	public Mp7JrsNodeCollection
{
public:

	/** Initializes the collection.
	  * @param maxElems Number of elements for which memory is initially allocated.
	  */
	virtual void Initialize(unsigned int maxElems) = 0;

	/** Adds a new element to the collection.
	  * @param toAdd Element to be added. Default element type: IMp7JrsAnalyticModelType_LocalType
	  */
	virtual void addElement(const Mp7JrsNodePtr &toAdd, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Sets the element at the given position in the collection.
	  * @param toSet New value of the element. Default element type: IMp7JrsAnalyticModelType_LocalType
	  * @param setAt Position of the element which shall be set.
	  */
	virtual void setElementAt(const Mp7JrsNodePtr &toSet, unsigned int setAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Inserts the element at the given position in the collection.
	  * @param toInsert Element to be inserted. Default element type: IMp7JrsAnalyticModelType_LocalType
	  * @param insertAt Position where the element will be inserted.
	  */
	virtual void insertElementAt(const Mp7JrsNodePtr &toInsert, unsigned int insertAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Removes all elements from the collection.
	  */
	virtual void removeAllElements(Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Removes the specified element from the collection.
	  * @param removeAt Position of the element to be removed. 
	  */
	virtual void removeElementAt(unsigned int removeAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Check whether the collection contains the given element.
	  * @param toCheck Element to be checked for. Default element type: IMp7JrsAnalyticModelType_LocalType
	  * @return True if the element is in the collection, false otherwise.
	  */
	virtual bool containsElement(const Mp7JrsNodePtr &toCheck) = 0;

	/** Get the current capacity of the collection.
	  * @return The number of elements for which memory has been allocated.
	  */
	virtual unsigned int curCapacity() const = 0;

	/** Gets a constant pointer to the element at the given position.
	  * @param Position of the element to be retrieved.
	  * @return A pointer to the given element or a null pointer if there is no element at the specified position. Default element type: Mp7JrsAnalyticModelType_LocalType.
	  */
	virtual const Mp7JrsNodePtr elementAt(unsigned int getAt) const = 0;

	/** Gets a pointer to the element at the given position.
	  * @param Position of the element to be retrieved.
	  * @return A pointer to the given element or a null pointer if there is no element at the specified position. Default element type: Mp7JrsAnalyticModelType_LocalType.
	  */
	virtual Mp7JrsNodePtr elementAt(unsigned int getAt) = 0;

	/** Gets an enumeration of all elements of the specified type
      * directly contained in the choice elements of the collection.
	  * @param The class id of the wanted elements.
	  * @return A (possibly empty) enumeration of all contained elements of type id.
	  */
	virtual Mp7JrsNodeEnum GetElementsContainingType(unsigned int id) const = 0;

	/** Gets an enumeration of all contained elements of the specified type.
	  * @param The class id of the wanted elements.
	  * @return A (possibly empty) enumeration of all contained elements of type id. 
	  */
	virtual Mp7JrsNodeEnum GetElementsOfType(unsigned int id) const = 0;

	/** Gets an enumeration of all contained elements.
	  * @return A (possibly empty) enumeration of all contained elements.
	  */
	virtual Mp7JrsNodeEnum GetElements() const = 0;

	/** Get the size of the collection.
	  * @return The current number of elements in the collection.
	  */
	virtual unsigned int size() const = 0;

	/** Allocate additional memory for the speciifed number of elements.
	  * @param length Number of elements to allocate memory for.
	  */
	virtual void ensureExtraCapacity(unsigned int length) = 0;

	// JRS: addition to Xerces collection
	/** Get the position of the specified element. 
	  * @param toCheck Element to be found in the collection. Default element type: IMp7JrsAnalyticModelType_LocalType
	  * @return The position of the specified element or -1 if the element has not been found.
	  */
	virtual int elementIndexOf(const Mp7JrsNodePtr &toCheck) const = 0;

};


class MP7JRS_EXPORT Mp7JrsAnalyticModelType_CollectionType :
	public IMp7JrsAnalyticModelType_CollectionType
{
	friend class Mp7JrsAnalyticModelType_CollectionTypeFactory;

public:
	virtual void Initialize(unsigned int maxElems);

	virtual void addElement(const Mp7JrsNodePtr &toAdd, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void setElementAt(const Mp7JrsNodePtr &toSet, unsigned int setAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void insertElementAt(const Mp7JrsNodePtr &toInsert, unsigned int insertAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void removeAllElements(Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void removeElementAt(unsigned int removeAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual bool containsElement(const Mp7JrsNodePtr &toCheck);

	virtual unsigned int curCapacity() const;

	virtual const Mp7JrsNodePtr elementAt(unsigned int getAt) const;

	virtual Mp7JrsNodePtr elementAt(unsigned int getAt);

	virtual Mp7JrsNodeEnum GetElementsContainingType(unsigned int id) const;

	virtual Mp7JrsNodeEnum GetElementsOfType(unsigned int id) const;

	virtual Mp7JrsNodeEnum GetElements() const;

	virtual unsigned int size() const;

	virtual void ensureExtraCapacity(unsigned int length);

	virtual int elementIndexOf(const Mp7JrsNodePtr &toCheck) const;

	/** Get the class name.
	 * @return The name of this class.
     */
	virtual XMLCh * ToText() const;

	/** Parse this type.
	 * @param txt buffer to parse from.
	 * @return true if parsing was successful, false otherwise.
	 */
	virtual bool Parse(const XMLCh * const txt);

	/** Serialialize this object to a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent node in DOM tree.
	 */
	virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

	/** Deserialize this object from a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent element in DOM tree.
	 * @param current Current element in DOM tree.
	 */
	virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

	virtual Mp7JrsNodePtr NodeFromXPath(const XMLCh *xpath) const;

// no includefile for extension defined 
// file Mp7JrsAnalyticModelType_CollectionType_ExtMethodDef.h


	virtual ~Mp7JrsAnalyticModelType_CollectionType();

protected:
	Mp7JrsAnalyticModelType_CollectionType();
	virtual void DeepCopy(const Mp7JrsNodePtr & original);
	virtual Mp7JrsNodeEnum GetAllChildElements() const { return GetElements(); }

private:
	Mp7JrsValueVectorOf <Mp7JrsNodePtr> * m_Item;
	bool dontSerializeWithContentName; // HACK


// no includefile for extension defined 
// file Mp7JrsAnalyticModelType_CollectionType_ExtPropDef.h


};


#endif // _79MP7JRSANALYTICMODELTYPE_COLLECTIONTYPE_H
