/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _97MP7JRSAUDIOHARMONICITYTYPE_H
#define _97MP7JRSAUDIOHARMONICITYTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsAudioHarmonicityTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsAudioHarmonicityType_ExtInclude.h


#include "Mp7JrsAudioDType.h"
#include "Mp7JrsDType.h"
#include "Mp7JrsMpeg7BaseType.h"
class IMp7JrsAudioDType;
class IMp7JrsAudioHarmonicityType;
class IMp7JrsAudioLLDScalarType;
typedef Mp7JrsPtr< IMp7JrsAudioDType > Mp7JrsAudioDPtr;
typedef Mp7JrsPtr< IMp7JrsAudioHarmonicityType> Mp7JrsAudioHarmonicityPtr;
typedef Mp7JrsPtr< IMp7JrsAudioLLDScalarType > Mp7JrsAudioLLDScalarPtr;

/** 
 * Generated interface IMp7JrsAudioHarmonicityType for class Mp7JrsAudioHarmonicityType<br>
 * Located at: audio-2001.xsd, line 159<br>
 * Classified: Class<br>
 * Derived from: AudioDType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsAudioHarmonicityType 
 :
        public IMp7JrsAudioDType
{
public:
    // TODO: make these protected?
    IMp7JrsAudioHarmonicityType();
    virtual ~IMp7JrsAudioHarmonicityType();
        /** @name Sequence

         */
        //@{
    /**
     * Get HarmonicRatio element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetHarmonicRatio() const = 0;

    /**
     * Set HarmonicRatio element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual void SetHarmonicRatio(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get UpperLimitOfHarmonicity element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetUpperLimitOfHarmonicity() const = 0;

    /**
     * Set UpperLimitOfHarmonicity element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual void SetUpperLimitOfHarmonicity(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsAudioHarmonicityType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsAudioHarmonicityType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsAudioHarmonicityType<br>
 * Located at: audio-2001.xsd, line 159<br>
 * Classified: Class<br>
 * Derived from: AudioDType (Class)<br>
 * Defined in audio-2001.xsd, line 159.<br>
 */
class MP7JRS_EXPORT Mp7JrsAudioHarmonicityType :
        public IMp7JrsAudioHarmonicityType
{
    friend class Mp7JrsAudioHarmonicityTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsAudioHarmonicityType
     
     * @return Mp7JrsPtr< Mp7JrsAudioDType >
     */
    virtual Mp7JrsPtr< Mp7JrsAudioDType > GetBase() const;
        /* @name Sequence

         */
        //@{
    /*
     * Get HarmonicRatio element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetHarmonicRatio() const;

    /*
     * Set HarmonicRatio element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual void SetHarmonicRatio(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get UpperLimitOfHarmonicity element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetUpperLimitOfHarmonicity() const;

    /*
     * Set UpperLimitOfHarmonicity element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAudioFundamentalFrequencyPtr</li>
     * <li>IMp7JrsAudioPowerPtr</li>
     * <li>IMp7JrsAudioSpectrumCentroidPtr</li>
     * <li>IMp7JrsAudioSpectrumSpreadPtr</li>
     * <li>IMp7JrsAudioWaveformPtr</li>
     * <li>IMp7JrsHarmonicSpectralCentroidPtr</li>
     * <li>IMp7JrsHarmonicSpectralDeviationPtr</li>
     * <li>IMp7JrsHarmonicSpectralSpreadPtr</li>
     * <li>IMp7JrsHarmonicSpectralVariationPtr</li>
     * <li>IMp7JrsLogAttackTimePtr</li>
     * <li>IMp7JrsSpectralCentroidPtr</li>
     * <li>IMp7JrsTemporalCentroidPtr</li>
     * </ul>
     */
    virtual void SetUpperLimitOfHarmonicity(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsAudioHarmonicityType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsAudioHarmonicityType();

protected:
    Mp7JrsAudioHarmonicityType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:

    // Base Class
    Mp7JrsPtr< Mp7JrsAudioDType > m_Base;

    Mp7JrsPtr< Mp7JrsNode > m_HarmonicRatio;
    Mp7JrsPtr< Mp7JrsNode > m_UpperLimitOfHarmonicity;

// no includefile for extension defined 
// file Mp7JrsAudioHarmonicityType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _97MP7JRSAUDIOHARMONICITYTYPE_H

