/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _595MP7JRSCONTOURSHAPETYPE_H
#define _595MP7JRSCONTOURSHAPETYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsContourShapeTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsContourShapeType_ExtInclude.h


#include "Mp7JrsDType.h"
#include "Mp7JrsMpeg7BaseType.h"
#include "Mp7JrsVisualDType.h"
class IMp7JrsContourShapeType;
class IMp7JrsContourShapeType_Peak_CollectionType;
class IMp7JrscurvatureType;
class IMp7Jrsunsigned7;
class IMp7JrsVisualDType;
typedef Mp7JrsPtr< IMp7JrsContourShapeType_Peak_CollectionType > Mp7JrsContourShapeType_Peak_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsContourShapeType> Mp7JrsContourShapePtr;
typedef Mp7JrsPtr< IMp7JrscurvatureType > Mp7JrscurvaturePtr;
typedef Mp7JrsPtr< IMp7Jrsunsigned7 > Mp7Jrsunsigned7Ptr;
typedef Mp7JrsPtr< IMp7JrsVisualDType > Mp7JrsVisualDPtr;

/** 
 * Generated interface IMp7JrsContourShapeType for class Mp7JrsContourShapeType<br>
 * Located at: visual-2001.xsd, line 776<br>
 * Classified: Class<br>
 * Derived from: VisualDType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsContourShapeType 
 :
        public IMp7JrsVisualDType
{
public:
    // TODO: make these protected?
    IMp7JrsContourShapeType();
    virtual ~IMp7JrsContourShapeType();
        /** @name Sequence

         */
        //@{
    /**
     * Get GlobalCurvature element.
     * @return Mp7JrscurvaturePtr
     */
    virtual Mp7JrscurvaturePtr GetGlobalCurvature() const = 0;

    /**
     * Set GlobalCurvature element.
     * @param item const Mp7JrscurvaturePtr &
     */
    virtual void SetGlobalCurvature(const Mp7JrscurvaturePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get PrototypeCurvature element.
     * @return Mp7JrscurvaturePtr
     */
    virtual Mp7JrscurvaturePtr GetPrototypeCurvature() const = 0;

    virtual bool IsValidPrototypeCurvature() const = 0;

    /**
     * Set PrototypeCurvature element.
     * @param item const Mp7JrscurvaturePtr &
     */
    virtual void SetPrototypeCurvature(const Mp7JrscurvaturePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate PrototypeCurvature element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatePrototypeCurvature() = 0;

    /**
     * Get HighestPeakY element.
     * @return Mp7Jrsunsigned7Ptr
     */
    virtual Mp7Jrsunsigned7Ptr GetHighestPeakY() const = 0;

    /**
     * Set HighestPeakY element.
     * @param item const Mp7Jrsunsigned7Ptr &
     */
    virtual void SetHighestPeakY(const Mp7Jrsunsigned7Ptr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get Peak element.
     * @return Mp7JrsContourShapeType_Peak_CollectionPtr
     */
    virtual Mp7JrsContourShapeType_Peak_CollectionPtr GetPeak() const = 0;

    /**
     * Set Peak element.
     * @param item const Mp7JrsContourShapeType_Peak_CollectionPtr &
     */
    virtual void SetPeak(const Mp7JrsContourShapeType_Peak_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsContourShapeType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsContourShapeType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsContourShapeType<br>
 * Located at: visual-2001.xsd, line 776<br>
 * Classified: Class<br>
 * Derived from: VisualDType (Class)<br>
 * Defined in visual-2001.xsd, line 776.<br>
 */
class MP7JRS_EXPORT Mp7JrsContourShapeType :
        public IMp7JrsContourShapeType
{
    friend class Mp7JrsContourShapeTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsContourShapeType
     
     * @return Mp7JrsPtr< Mp7JrsVisualDType >
     */
    virtual Mp7JrsPtr< Mp7JrsVisualDType > GetBase() const;
        /* @name Sequence

         */
        //@{
    /*
     * Get GlobalCurvature element.
     * @return Mp7JrscurvaturePtr
     */
    virtual Mp7JrscurvaturePtr GetGlobalCurvature() const;

    /*
     * Set GlobalCurvature element.
     * @param item const Mp7JrscurvaturePtr &
     */
    virtual void SetGlobalCurvature(const Mp7JrscurvaturePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get PrototypeCurvature element.
     * @return Mp7JrscurvaturePtr
     */
    virtual Mp7JrscurvaturePtr GetPrototypeCurvature() const;

    virtual bool IsValidPrototypeCurvature() const;

    /*
     * Set PrototypeCurvature element.
     * @param item const Mp7JrscurvaturePtr &
     */
    virtual void SetPrototypeCurvature(const Mp7JrscurvaturePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate PrototypeCurvature element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatePrototypeCurvature();

    /*
     * Get HighestPeakY element.
     * @return Mp7Jrsunsigned7Ptr
     */
    virtual Mp7Jrsunsigned7Ptr GetHighestPeakY() const;

    /*
     * Set HighestPeakY element.
     * @param item const Mp7Jrsunsigned7Ptr &
     */
    virtual void SetHighestPeakY(const Mp7Jrsunsigned7Ptr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get Peak element.
     * @return Mp7JrsContourShapeType_Peak_CollectionPtr
     */
    virtual Mp7JrsContourShapeType_Peak_CollectionPtr GetPeak() const;

    /*
     * Set Peak element.
     * @param item const Mp7JrsContourShapeType_Peak_CollectionPtr &
     */
    virtual void SetPeak(const Mp7JrsContourShapeType_Peak_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsContourShapeType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsContourShapeType();

protected:
    Mp7JrsContourShapeType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:

    // Base Class
    Mp7JrsPtr< Mp7JrsVisualDType > m_Base;

    Mp7JrscurvaturePtr m_GlobalCurvature;
    Mp7JrscurvaturePtr m_PrototypeCurvature;
    bool m_PrototypeCurvature_Exist; // For optional elements 
    Mp7Jrsunsigned7Ptr m_HighestPeakY;
    Mp7JrsContourShapeType_Peak_CollectionPtr m_Peak;

// no includefile for extension defined 
// file Mp7JrsContourShapeType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _595MP7JRSCONTOURSHAPETYPE_H

