/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _665MP7JRSCREATORTYPE_H
#define _665MP7JRSCREATORTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsCreatorTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsCreatorType_ExtInclude.h


#include "Mp7JrsMediaAgentType.h"
class IMp7JrsAgentType;
class IMp7JrsControlledTermUseType;
class IMp7JrsCreatorType;
class IMp7JrsCreatorType_Character_CollectionType;
class IMp7JrsCreatorType_Instrument_CollectionType;
class IMp7JrsMediaAgentType;
class IMp7JrsReferenceType;
typedef Mp7JrsPtr< IMp7JrsAgentType > Mp7JrsAgentPtr;
typedef Mp7JrsPtr< IMp7JrsControlledTermUseType > Mp7JrsControlledTermUsePtr;
typedef Mp7JrsPtr< IMp7JrsCreatorType_Character_CollectionType > Mp7JrsCreatorType_Character_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreatorType_Instrument_CollectionType > Mp7JrsCreatorType_Instrument_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreatorType> Mp7JrsCreatorPtr;
typedef Mp7JrsPtr< IMp7JrsMediaAgentType > Mp7JrsMediaAgentPtr;
typedef Mp7JrsPtr< IMp7JrsReferenceType > Mp7JrsReferencePtr;

/** 
 * Generated interface IMp7JrsCreatorType for class Mp7JrsCreatorType<br>
 * Located at: mds-2001.xsd, line 2563<br>
 * Classified: Class<br>
 * Derived from: MediaAgentType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsCreatorType 
 :
        public IMp7JrsMediaAgentType
{
public:
    // TODO: make these protected?
    IMp7JrsCreatorType();
    virtual ~IMp7JrsCreatorType();
        /** @name Sequence

         */
        //@{
    /**
     * Get Character element.
     * @return Mp7JrsCreatorType_Character_CollectionPtr
     */
    virtual Mp7JrsCreatorType_Character_CollectionPtr GetCharacter() const = 0;

    /**
     * Set Character element.
     * @param item const Mp7JrsCreatorType_Character_CollectionPtr &
     */
    virtual void SetCharacter(const Mp7JrsCreatorType_Character_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get Instrument element.
     * @return Mp7JrsCreatorType_Instrument_CollectionPtr
     */
    virtual Mp7JrsCreatorType_Instrument_CollectionPtr GetInstrument() const = 0;

    /**
     * Set Instrument element.
     * @param item const Mp7JrsCreatorType_Instrument_CollectionPtr &
     */
    virtual void SetInstrument(const Mp7JrsCreatorType_Instrument_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
        /** @name Sequence

         */
        //@{
    /**
     * Get Role element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @return Mp7JrsControlledTermUsePtr
     */
    virtual Mp7JrsControlledTermUsePtr GetRole() const = 0;

    /**
     * Set Role element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @param item const Mp7JrsControlledTermUsePtr &
     */
    virtual void SetRole(const Mp7JrsControlledTermUsePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        /** @name Choice

         */
        //@{
    /**
     * Get Agent element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetAgent() const = 0;

    /**
     * Set Agent element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual void SetAgent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get AgentRef element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @return Mp7JrsReferencePtr
     */
    virtual Mp7JrsReferencePtr GetAgentRef() const = 0;

    /**
     * Set AgentRef element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @param item const Mp7JrsReferencePtr &
     */
    virtual void SetAgentRef(const Mp7JrsReferencePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
        //@}
// no includefile for extension defined 
// file Mp7JrsCreatorType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsCreatorType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsCreatorType<br>
 * Located at: mds-2001.xsd, line 2563<br>
 * Classified: Class<br>
 * Derived from: MediaAgentType (Class)<br>
 * Defined in mds-2001.xsd, line 2563.<br>
 */
class MP7JRS_EXPORT Mp7JrsCreatorType :
        public IMp7JrsCreatorType
{
    friend class Mp7JrsCreatorTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsCreatorType
     
     * @return Mp7JrsPtr< Mp7JrsMediaAgentType >
     */
    virtual Mp7JrsPtr< Mp7JrsMediaAgentType > GetBase() const;
        /* @name Sequence

         */
        //@{
    /*
     * Get Character element.
     * @return Mp7JrsCreatorType_Character_CollectionPtr
     */
    virtual Mp7JrsCreatorType_Character_CollectionPtr GetCharacter() const;

    /*
     * Set Character element.
     * @param item const Mp7JrsCreatorType_Character_CollectionPtr &
     */
    virtual void SetCharacter(const Mp7JrsCreatorType_Character_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get Instrument element.
     * @return Mp7JrsCreatorType_Instrument_CollectionPtr
     */
    virtual Mp7JrsCreatorType_Instrument_CollectionPtr GetInstrument() const;

    /*
     * Set Instrument element.
     * @param item const Mp7JrsCreatorType_Instrument_CollectionPtr &
     */
    virtual void SetInstrument(const Mp7JrsCreatorType_Instrument_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
        /* @name Sequence

         */
        //@{
    /*
     * Get Role element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @return Mp7JrsControlledTermUsePtr
     */
    virtual Mp7JrsControlledTermUsePtr GetRole() const;

    /*
     * Set Role element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @param item const Mp7JrsControlledTermUsePtr &
     */
    virtual void SetRole(const Mp7JrsControlledTermUsePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        /* @name Choice

         */
        //@{
    /*
     * Get Agent element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetAgent() const;

    /*
     * Set Agent element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual void SetAgent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get AgentRef element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @return Mp7JrsReferencePtr
     */
    virtual Mp7JrsReferencePtr GetAgentRef() const;

    /*
     * Set AgentRef element.
<br>
     * (Inherited from Mp7JrsMediaAgentType)
     * @param item const Mp7JrsReferencePtr &
     */
    virtual void SetAgentRef(const Mp7JrsReferencePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsCreatorType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsCreatorType();

protected:
    Mp7JrsCreatorType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:

    // Base Class
    Mp7JrsPtr< Mp7JrsMediaAgentType > m_Base;

    Mp7JrsCreatorType_Character_CollectionPtr m_Character;
    Mp7JrsCreatorType_Instrument_CollectionPtr m_Instrument;

// no includefile for extension defined 
// file Mp7JrsCreatorType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _665MP7JRSCREATORTYPE_H

