/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _857MP7JRSFILTERINGTYPE_H
#define _857MP7JRSFILTERINGTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsFilteringTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsFilteringType_ExtInclude.h


class IMp7JrsFilteringType;
class IMp7JrsFilterType;
class IMp7JrspaddingType;
class IMp7JrsSignalPlaneSampleType;
typedef Mp7JrsPtr< IMp7JrsFilteringType> Mp7JrsFilteringPtr;
typedef Mp7JrsPtr< IMp7JrsFilterType > Mp7JrsFilterPtr;
typedef Mp7JrsPtr< IMp7JrspaddingType > Mp7JrspaddingPtr;
typedef Mp7JrsPtr< IMp7JrsSignalPlaneSampleType > Mp7JrsSignalPlaneSamplePtr;

/** 
 * Generated interface IMp7JrsFilteringType for class Mp7JrsFilteringType<br>
 * Located at: mds-2001.xsd, line 4818<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsFilteringType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsFilteringType();
    virtual ~IMp7JrsFilteringType();
    /**
     * Get xPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GetxPad() const = 0;

    /**
     * Get xPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistxPad() const = 0;

    /**
     * Set xPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SetxPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate xPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatexPad() = 0;

    /**
     * Get yPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GetyPad() const = 0;

    /**
     * Get yPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistyPad() const = 0;

    /**
     * Set yPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SetyPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate yPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateyPad() = 0;

    /**
     * Get zPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GetzPad() const = 0;

    /**
     * Get zPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistzPad() const = 0;

    /**
     * Set zPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SetzPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate zPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatezPad() = 0;

    /**
     * Get tPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GettPad() const = 0;

    /**
     * Get tPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttPad() const = 0;

    /**
     * Set tPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SettPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate tPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetPad() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get Filter element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsFilter1DPtr</li>
     * <li>IMp7JrsFilter2DPtr</li>
     * <li>IMp7JrsFilterSeparablePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetFilter() const = 0;

    /**
     * Set Filter element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsFilter1DPtr</li>
     * <li>IMp7JrsFilter2DPtr</li>
     * <li>IMp7JrsFilterSeparablePtr</li>
     * </ul>
     */
    virtual void SetFilter(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get PadSize element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetPadSize() const = 0;

    virtual bool IsValidPadSize() const = 0;

    /**
     * Set PadSize element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetPadSize(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate PadSize element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatePadSize() = 0;

    /**
     * Get Shift element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetShift() const = 0;

    virtual bool IsValidShift() const = 0;

    /**
     * Set Shift element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetShift(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Shift element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateShift() = 0;

    /**
     * Get CropStart element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetCropStart() const = 0;

    virtual bool IsValidCropStart() const = 0;

    /**
     * Set CropStart element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetCropStart(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate CropStart element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateCropStart() = 0;

    /**
     * Get CropEnd element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetCropEnd() const = 0;

    virtual bool IsValidCropEnd() const = 0;

    /**
     * Set CropEnd element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetCropEnd(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate CropEnd element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateCropEnd() = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsFilteringType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsFilteringType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsFilteringType<br>
 * Located at: mds-2001.xsd, line 4818<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 4818.<br>
 */
class MP7JRS_EXPORT Mp7JrsFilteringType :
        public IMp7JrsFilteringType
{
    friend class Mp7JrsFilteringTypeFactory; // constructs objects

public:
    /*
     * Get xPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GetxPad() const;

    /*
     * Get xPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistxPad() const;

    /*
     * Set xPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SetxPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate xPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatexPad();

    /*
     * Get yPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GetyPad() const;

    /*
     * Get yPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistyPad() const;

    /*
     * Set yPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SetyPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate yPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateyPad();

    /*
     * Get zPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GetzPad() const;

    /*
     * Get zPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistzPad() const;

    /*
     * Set zPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SetzPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate zPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatezPad();

    /*
     * Get tPad attribute.
     * @return Mp7JrspaddingPtr
     */
    virtual Mp7JrspaddingPtr GettPad() const;

    /*
     * Get tPad attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttPad() const;

    /*
     * Set tPad attribute.
     * @param item const Mp7JrspaddingPtr &
     */
    virtual void SettPad(const Mp7JrspaddingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate tPad attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetPad();

        /* @name Sequence

         */
        //@{
    /*
     * Get Filter element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsFilter1DPtr</li>
     * <li>IMp7JrsFilter2DPtr</li>
     * <li>IMp7JrsFilterSeparablePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetFilter() const;

    /*
     * Set Filter element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsFilter1DPtr</li>
     * <li>IMp7JrsFilter2DPtr</li>
     * <li>IMp7JrsFilterSeparablePtr</li>
     * </ul>
     */
    virtual void SetFilter(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get PadSize element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetPadSize() const;

    virtual bool IsValidPadSize() const;

    /*
     * Set PadSize element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetPadSize(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate PadSize element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatePadSize();

    /*
     * Get Shift element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetShift() const;

    virtual bool IsValidShift() const;

    /*
     * Set Shift element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetShift(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Shift element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateShift();

    /*
     * Get CropStart element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetCropStart() const;

    virtual bool IsValidCropStart() const;

    /*
     * Set CropStart element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetCropStart(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate CropStart element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateCropStart();

    /*
     * Get CropEnd element.
     * @return Mp7JrsSignalPlaneSamplePtr
     */
    virtual Mp7JrsSignalPlaneSamplePtr GetCropEnd() const;

    virtual bool IsValidCropEnd() const;

    /*
     * Set CropEnd element.
     * @param item const Mp7JrsSignalPlaneSamplePtr &
     */
    virtual void SetCropEnd(const Mp7JrsSignalPlaneSamplePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate CropEnd element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateCropEnd();

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsFilteringType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsFilteringType();

protected:
    Mp7JrsFilteringType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7JrspaddingPtr m_xPad;
    bool m_xPad_Exist;
    Mp7JrspaddingPtr m_xPad_Default;
    Mp7JrspaddingPtr m_yPad;
    bool m_yPad_Exist;
    Mp7JrspaddingPtr m_yPad_Default;
    Mp7JrspaddingPtr m_zPad;
    bool m_zPad_Exist;
    Mp7JrspaddingPtr m_zPad_Default;
    Mp7JrspaddingPtr m_tPad;
    bool m_tPad_Exist;
    Mp7JrspaddingPtr m_tPad_Default;


    Mp7JrsPtr< Mp7JrsNode > m_Filter;
    Mp7JrsSignalPlaneSamplePtr m_PadSize;
    bool m_PadSize_Exist; // For optional elements 
    Mp7JrsSignalPlaneSamplePtr m_Shift;
    bool m_Shift_Exist; // For optional elements 
    Mp7JrsSignalPlaneSamplePtr m_CropStart;
    bool m_CropStart_Exist; // For optional elements 
    Mp7JrsSignalPlaneSamplePtr m_CropEnd;
    bool m_CropEnd_Exist; // For optional elements 

// no includefile for extension defined 
// file Mp7JrsFilteringType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _857MP7JRSFILTERINGTYPE_H

