/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _873MP7JRSFLOATDIAGONALMATRIXTYPE_H
#define _873MP7JRSFLOATDIAGONALMATRIXTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsFloatDiagonalMatrixTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsFloatDiagonalMatrixType_ExtInclude.h


#include "Mp7JrsfloatVector.h"
class IMp7Jrsdim_LocalType;
class IMp7JrsFloatDiagonalMatrixType;
class IMp7JrsfloatVector;
typedef Mp7JrsPtr< IMp7Jrsdim_LocalType > Mp7Jrsdim_LocalPtr;
typedef Mp7JrsPtr< IMp7JrsFloatDiagonalMatrixType> Mp7JrsFloatDiagonalMatrixPtr;
typedef Mp7JrsPtr< IMp7JrsfloatVector > Mp7JrsfloatVectorPtr;

/** 
 * Generated interface IMp7JrsFloatDiagonalMatrixType for class Mp7JrsFloatDiagonalMatrixType<br>
 * Located at: mds-2001.xsd, line 759<br>
 * Classified: Class<br>
 * Derived from: floatVector (Collection)<br>
 * Derived from: floatVector (Collection)<br>
 */
class MP7JRS_EXPORT IMp7JrsFloatDiagonalMatrixType 
 :
        public IMp7JrsfloatVector
{
public:
    // TODO: make these protected?
    IMp7JrsFloatDiagonalMatrixType();
    virtual ~IMp7JrsFloatDiagonalMatrixType();
    /**
     * Retrieves the base collection of Mp7JrsFloatDiagonalMatrixType
     
     * @return Mp7JrsPtr< Mp7JrsfloatVector >
     */
    virtual Mp7JrsPtr< Mp7JrsfloatVector > GetBaseCollection() const = 0;


    /**
     * Initializes the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param maxElems Number of elements for which memory is initially allocated.
     */
    virtual void Initialize(unsigned int maxElems) = 0;


    /**
     * Adds a new element to the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param toAdd Element to be added. Default element type: float
     */
    virtual void addElement(const float &toAdd, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Sets the element at the given position in the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param toSet New value of the element. Default element type: float
     * @param setAt Position of the element which shall be set.
     */
    virtual void setElementAt(const float &toSet, unsigned int setAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Inserts the element at the given position in the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param toInsert Element to be inserted. Default element type: float
     * @param insertAt Position where the element will be inserted.
     */
    virtual void insertElementAt(const float &toInsert, unsigned int insertAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Removes all elements from the collection.
     * (Inherited from Mp7JrsfloatVector)
     */
    virtual void removeAllElements(Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Removes the specified element from the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param removeAt Position of the element to be removed. 
     */
    virtual void removeElementAt(unsigned int removeAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;



    /**
     * Check whether the collection contains the given element.
     * (Inherited from Mp7JrsfloatVector)
     * @param toCheck Element to be checked for. Default element type: float
     * @return True if the element is in the collection, false otherwise.
     */
    virtual bool containsElement(const float &toCheck) = 0;


    /**
     * Get the current capacity of the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @return The number of elements for which memory has been allocated.
     */
    virtual unsigned int curCapacity() const = 0;


    /**
     * Gets a constant pointer to the element at the given position.
     * (Inherited from Mp7JrsfloatVector)
     * @param Position of the element to be retrieved.
     * @return A pointer to the given element or a null pointer if there is no element at the specified position. Default element type: float.
     */
    virtual const float elementAt(unsigned int getAt) const = 0;


    /**
     * Gets a pointer to the element at the given position.
     * (Inherited from Mp7JrsfloatVector)
     * @param Position of the element to be retrieved.
     * @return A pointer to the given element or a null pointer if there is no element at the specified position. Default element type: float.
     */
    virtual float elementAt(unsigned int getAt) = 0;


    /**
     * Get the size of the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @return The current number of elements in the collection.
     */
    virtual unsigned int size() const = 0;


    /**
     * Allocate additional memory for the speciifed number of elements.
     * (Inherited from Mp7JrsfloatVector)
     * @param length Number of elements to allocate memory for.
     */
    virtual void ensureExtraCapacity(unsigned int length) = 0;


    // JRS: addition to Xerces collection
    /**
     * Get the position of the specified element. 
     * (Inherited from Mp7JrsfloatVector)
     * @param toCheck Element to be found in the collection. Default element type: float
     * @return The position of the specified element or -1 if the element has not been found.
     */
    virtual int elementIndexOf(const float &toCheck) const = 0;


    /**
     * Get dim attribute.
     * @return Mp7Jrsdim_LocalPtr
     */
    virtual Mp7Jrsdim_LocalPtr Getdim() const = 0;

    /**
     * Set dim attribute.
     * @param item const Mp7Jrsdim_LocalPtr &
     */
    virtual void Setdim(const Mp7Jrsdim_LocalPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

// no includefile for extension defined 
// file Mp7JrsFloatDiagonalMatrixType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsFloatDiagonalMatrixType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsFloatDiagonalMatrixType<br>
 * Located at: mds-2001.xsd, line 759<br>
 * Classified: Class<br>
 * Derived from: floatVector (Collection)<br>
 * Derived from: floatVector (Collection)<br>
 * Defined in mds-2001.xsd, line 759.<br>
 */
class MP7JRS_EXPORT Mp7JrsFloatDiagonalMatrixType :
        public IMp7JrsFloatDiagonalMatrixType
{
    friend class Mp7JrsFloatDiagonalMatrixTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsFloatDiagonalMatrixType
     
     * @return Mp7JrsPtr< Mp7JrsfloatVector >
     */
    virtual Mp7JrsPtr< Mp7JrsfloatVector > GetBase() const;
    /*
     * Retrieves the base collection of Mp7JrsFloatDiagonalMatrixType
     
     * @return Mp7JrsPtr< Mp7JrsfloatVector >
     */
    virtual Mp7JrsPtr< Mp7JrsfloatVector > GetBaseCollection() const;


    /*
     * Initializes the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param maxElems Number of elements for which memory is initially allocated.
     */
    virtual void Initialize(unsigned int maxElems);


    /*
     * Adds a new element to the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param toAdd Element to be added. Default element type: float
     */
    virtual void addElement(const float &toAdd, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Sets the element at the given position in the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param toSet New value of the element. Default element type: float
     * @param setAt Position of the element which shall be set.
     */
    virtual void setElementAt(const float &toSet, unsigned int setAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Inserts the element at the given position in the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param toInsert Element to be inserted. Default element type: float
     * @param insertAt Position where the element will be inserted.
     */
    virtual void insertElementAt(const float &toInsert, unsigned int insertAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Removes all elements from the collection.
     * (Inherited from Mp7JrsfloatVector)
     */
    virtual void removeAllElements(Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Removes the specified element from the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @param removeAt Position of the element to be removed. 
     */
    virtual void removeElementAt(unsigned int removeAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);



    /*
     * Check whether the collection contains the given element.
     * (Inherited from Mp7JrsfloatVector)
     * @param toCheck Element to be checked for. Default element type: float
     * @return True if the element is in the collection, false otherwise.
     */
    virtual bool containsElement(const float &toCheck);


    /*
     * Get the current capacity of the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @return The number of elements for which memory has been allocated.
     */
    virtual unsigned int curCapacity() const;


    /*
     * Gets a constant pointer to the element at the given position.
     * (Inherited from Mp7JrsfloatVector)
     * @param Position of the element to be retrieved.
     * @return A pointer to the given element or a null pointer if there is no element at the specified position. Default element type: float.
     */
    virtual const float elementAt(unsigned int getAt) const;


    /*
     * Gets a pointer to the element at the given position.
     * (Inherited from Mp7JrsfloatVector)
     * @param Position of the element to be retrieved.
     * @return A pointer to the given element or a null pointer if there is no element at the specified position. Default element type: float.
     */
    virtual float elementAt(unsigned int getAt);


    /*
     * Get the size of the collection.
     * (Inherited from Mp7JrsfloatVector)
     * @return The current number of elements in the collection.
     */
    virtual unsigned int size() const;


    /*
     * Allocate additional memory for the speciifed number of elements.
     * (Inherited from Mp7JrsfloatVector)
     * @param length Number of elements to allocate memory for.
     */
    virtual void ensureExtraCapacity(unsigned int length);


    // JRS: addition to Xerces collection
    /*
     * Get the position of the specified element. 
     * (Inherited from Mp7JrsfloatVector)
     * @param toCheck Element to be found in the collection. Default element type: float
     * @return The position of the specified element or -1 if the element has not been found.
     */
    virtual int elementIndexOf(const float &toCheck) const;


    /*
     * Get dim attribute.
     * @return Mp7Jrsdim_LocalPtr
     */
    virtual Mp7Jrsdim_LocalPtr Getdim() const;

    /*
     * Set dim attribute.
     * @param item const Mp7Jrsdim_LocalPtr &
     */
    virtual void Setdim(const Mp7Jrsdim_LocalPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsFloatDiagonalMatrixType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsFloatDiagonalMatrixType();

protected:
    Mp7JrsFloatDiagonalMatrixType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7Jrsdim_LocalPtr m_dim;

    // Base Collection
    Mp7JrsPtr< Mp7JrsfloatVector > m_Base;


// no includefile for extension defined 
// file Mp7JrsFloatDiagonalMatrixType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _873MP7JRSFLOATDIAGONALMATRIXTYPE_H

