/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1131MP7JRSMEDIAAGENTTYPE_H
#define _1131MP7JRSMEDIAAGENTTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsMediaAgentTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsMediaAgentType_ExtInclude.h


class IMp7JrsAgentType;
class IMp7JrsControlledTermUseType;
class IMp7JrsMediaAgentType;
class IMp7JrsReferenceType;
typedef Mp7JrsPtr< IMp7JrsAgentType > Mp7JrsAgentPtr;
typedef Mp7JrsPtr< IMp7JrsControlledTermUseType > Mp7JrsControlledTermUsePtr;
typedef Mp7JrsPtr< IMp7JrsMediaAgentType> Mp7JrsMediaAgentPtr;
typedef Mp7JrsPtr< IMp7JrsReferenceType > Mp7JrsReferencePtr;

/** 
 * Generated interface IMp7JrsMediaAgentType for class Mp7JrsMediaAgentType<br>
 * Located at: mds-2001.xsd, line 2574<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsMediaAgentType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsMediaAgentType();
    virtual ~IMp7JrsMediaAgentType();
        /** @name Sequence

         */
        //@{
    /**
     * Get Role element.
     * @return Mp7JrsControlledTermUsePtr
     */
    virtual Mp7JrsControlledTermUsePtr GetRole() const = 0;

    /**
     * Set Role element.
     * @param item const Mp7JrsControlledTermUsePtr &
     */
    virtual void SetRole(const Mp7JrsControlledTermUsePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        /** @name Choice

         */
        //@{
    /**
     * Get Agent element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetAgent() const = 0;

    /**
     * Set Agent element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual void SetAgent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get AgentRef element.
     * @return Mp7JrsReferencePtr
     */
    virtual Mp7JrsReferencePtr GetAgentRef() const = 0;

    /**
     * Set AgentRef element.
     * @param item const Mp7JrsReferencePtr &
     */
    virtual void SetAgentRef(const Mp7JrsReferencePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
        //@}
// no includefile for extension defined 
// file Mp7JrsMediaAgentType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsMediaAgentType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsMediaAgentType<br>
 * Located at: mds-2001.xsd, line 2574<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 2574.<br>
 */
class MP7JRS_EXPORT Mp7JrsMediaAgentType :
        public IMp7JrsMediaAgentType
{
    friend class Mp7JrsMediaAgentTypeFactory; // constructs objects

public:
        /* @name Sequence

         */
        //@{
    /*
     * Get Role element.
     * @return Mp7JrsControlledTermUsePtr
     */
    virtual Mp7JrsControlledTermUsePtr GetRole() const;

    /*
     * Set Role element.
     * @param item const Mp7JrsControlledTermUsePtr &
     */
    virtual void SetRole(const Mp7JrsControlledTermUsePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        /* @name Choice

         */
        //@{
    /*
     * Get Agent element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetAgent() const;

    /*
     * Set Agent element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual void SetAgent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get AgentRef element.
     * @return Mp7JrsReferencePtr
     */
    virtual Mp7JrsReferencePtr GetAgentRef() const;

    /*
     * Set AgentRef element.
     * @param item const Mp7JrsReferencePtr &
     */
    virtual void SetAgentRef(const Mp7JrsReferencePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsMediaAgentType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsMediaAgentType();

protected:
    Mp7JrsMediaAgentType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:


    Mp7JrsControlledTermUsePtr m_Role;
// DefinionChoice
    Mp7JrsPtr< Mp7JrsNode > m_Agent;
    Mp7JrsReferencePtr m_AgentRef;
// End DefinionChoice

// no includefile for extension defined 
// file Mp7JrsMediaAgentType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1131MP7JRSMEDIAAGENTTYPE_H

