/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1199MP7JRSMEDIALOCATORTYPE_H
#define _1199MP7JRSMEDIALOCATORTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsMediaLocatorTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsMediaLocatorType_ExtInclude.h


class IMp7JrsInlineMediaType;
class IMp7JrsMediaLocatorType;
typedef Mp7JrsPtr< IMp7JrsInlineMediaType > Mp7JrsInlineMediaPtr;
typedef Mp7JrsPtr< IMp7JrsMediaLocatorType> Mp7JrsMediaLocatorPtr;

/** 
 * Generated interface IMp7JrsMediaLocatorType for class Mp7JrsMediaLocatorType<br>
 * Located at: mds-2001.xsd, line 1093<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsMediaLocatorType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsMediaLocatorType();
    virtual ~IMp7JrsMediaLocatorType();
        /** @name Sequence

         */
        //@{
        /** @name Choice

         */
        //@{
    /**
     * Get MediaUri element.
     * @return XMLCh *
     */
    virtual XMLCh * GetMediaUri() const = 0;

    /**
     * Set MediaUri element.
     * @param item XMLCh *
     */
    virtual void SetMediaUri(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get InlineMedia element.
     * @return Mp7JrsInlineMediaPtr
     */
    virtual Mp7JrsInlineMediaPtr GetInlineMedia() const = 0;

    /**
     * Set InlineMedia element.
     * @param item const Mp7JrsInlineMediaPtr &
     */
    virtual void SetInlineMedia(const Mp7JrsInlineMediaPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
    /**
     * Get StreamID element.
     * @return unsigned
     */
    virtual unsigned GetStreamID() const = 0;

    virtual bool IsValidStreamID() const = 0;

    /**
     * Set StreamID element.
     * @param item unsigned
     */
    virtual void SetStreamID(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate StreamID element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateStreamID() = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsMediaLocatorType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsMediaLocatorType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsMediaLocatorType<br>
 * Located at: mds-2001.xsd, line 1093<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 1093.<br>
 */
class MP7JRS_EXPORT Mp7JrsMediaLocatorType :
        public IMp7JrsMediaLocatorType
{
    friend class Mp7JrsMediaLocatorTypeFactory; // constructs objects

public:
        /* @name Sequence

         */
        //@{
        /* @name Choice

         */
        //@{
    /*
     * Get MediaUri element.
     * @return XMLCh *
     */
    virtual XMLCh * GetMediaUri() const;

    /*
     * Set MediaUri element.
     * @param item XMLCh *
     */
    virtual void SetMediaUri(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get InlineMedia element.
     * @return Mp7JrsInlineMediaPtr
     */
    virtual Mp7JrsInlineMediaPtr GetInlineMedia() const;

    /*
     * Set InlineMedia element.
     * @param item const Mp7JrsInlineMediaPtr &
     */
    virtual void SetInlineMedia(const Mp7JrsInlineMediaPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
    /*
     * Get StreamID element.
     * @return unsigned
     */
    virtual unsigned GetStreamID() const;

    virtual bool IsValidStreamID() const;

    /*
     * Set StreamID element.
     * @param item unsigned
     */
    virtual void SetStreamID(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate StreamID element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateStreamID();

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsMediaLocatorType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsMediaLocatorType();

protected:
    Mp7JrsMediaLocatorType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:


// DefinionChoice
    XMLCh * m_MediaUri;
    Mp7JrsInlineMediaPtr m_InlineMedia;
// End DefinionChoice
    unsigned m_StreamID;
    bool m_StreamID_Exist; // For optional elements 

// no includefile for extension defined 
// file Mp7JrsMediaLocatorType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1199MP7JRSMEDIALOCATORTYPE_H

