/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1227MP7JRSMEDIAREVIEWTYPE_H
#define _1227MP7JRSMEDIAREVIEWTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsMediaReviewTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsMediaReviewType_ExtInclude.h


class IMp7JrsAgentType;
class IMp7JrsMediaReviewType;
class IMp7JrsMediaReviewType_FreeTextReview_CollectionType;
class IMp7JrsRatingType;
class IMp7JrsRelatedMaterialType;
typedef Mp7JrsPtr< IMp7JrsAgentType > Mp7JrsAgentPtr;
typedef Mp7JrsPtr< IMp7JrsMediaReviewType_FreeTextReview_CollectionType > Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsMediaReviewType> Mp7JrsMediaReviewPtr;
typedef Mp7JrsPtr< IMp7JrsRatingType > Mp7JrsRatingPtr;
typedef Mp7JrsPtr< IMp7JrsRelatedMaterialType > Mp7JrsRelatedMaterialPtr;

/** 
 * Generated interface IMp7JrsMediaReviewType for class Mp7JrsMediaReviewType<br>
 * Located at: mds-2001.xsd, line 2699<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsMediaReviewType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsMediaReviewType();
    virtual ~IMp7JrsMediaReviewType();
        /** @name Sequence

         */
        //@{
    /**
     * Get Rating element.
     * @return Mp7JrsRatingPtr
     */
    virtual Mp7JrsRatingPtr GetRating() const = 0;

    virtual bool IsValidRating() const = 0;

    /**
     * Set Rating element.
     * @param item const Mp7JrsRatingPtr &
     */
    virtual void SetRating(const Mp7JrsRatingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Rating element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateRating() = 0;

    /**
     * Get FreeTextReview element.
     * @return Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr
     */
    virtual Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr GetFreeTextReview() const = 0;

    /**
     * Set FreeTextReview element.
     * @param item const Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr &
     */
    virtual void SetFreeTextReview(const Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get ReviewReference element.
     * @return Mp7JrsRelatedMaterialPtr
     */
    virtual Mp7JrsRelatedMaterialPtr GetReviewReference() const = 0;

    virtual bool IsValidReviewReference() const = 0;

    /**
     * Set ReviewReference element.
     * @param item const Mp7JrsRelatedMaterialPtr &
     */
    virtual void SetReviewReference(const Mp7JrsRelatedMaterialPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate ReviewReference element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateReviewReference() = 0;

    /**
     * Get Reviewer element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetReviewer() const = 0;

    virtual bool IsValidReviewer() const = 0;

    /**
     * Set Reviewer element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual void SetReviewer(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Reviewer element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateReviewer() = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsMediaReviewType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsMediaReviewType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsMediaReviewType<br>
 * Located at: mds-2001.xsd, line 2699<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 2699.<br>
 */
class MP7JRS_EXPORT Mp7JrsMediaReviewType :
        public IMp7JrsMediaReviewType
{
    friend class Mp7JrsMediaReviewTypeFactory; // constructs objects

public:
        /* @name Sequence

         */
        //@{
    /*
     * Get Rating element.
     * @return Mp7JrsRatingPtr
     */
    virtual Mp7JrsRatingPtr GetRating() const;

    virtual bool IsValidRating() const;

    /*
     * Set Rating element.
     * @param item const Mp7JrsRatingPtr &
     */
    virtual void SetRating(const Mp7JrsRatingPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Rating element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateRating();

    /*
     * Get FreeTextReview element.
     * @return Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr
     */
    virtual Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr GetFreeTextReview() const;

    /*
     * Set FreeTextReview element.
     * @param item const Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr &
     */
    virtual void SetFreeTextReview(const Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get ReviewReference element.
     * @return Mp7JrsRelatedMaterialPtr
     */
    virtual Mp7JrsRelatedMaterialPtr GetReviewReference() const;

    virtual bool IsValidReviewReference() const;

    /*
     * Set ReviewReference element.
     * @param item const Mp7JrsRelatedMaterialPtr &
     */
    virtual void SetReviewReference(const Mp7JrsRelatedMaterialPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate ReviewReference element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateReviewReference();

    /*
     * Get Reviewer element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetReviewer() const;

    virtual bool IsValidReviewer() const;

    /*
     * Set Reviewer element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsOrganizationPtr</li>
     * <li>IMp7JrsPersonGroupPtr</li>
     * <li>IMp7JrsPersonPtr</li>
     * </ul>
     */
    virtual void SetReviewer(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Reviewer element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateReviewer();

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsMediaReviewType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsMediaReviewType();

protected:
    Mp7JrsMediaReviewType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:


    Mp7JrsRatingPtr m_Rating;
    bool m_Rating_Exist; // For optional elements 
    Mp7JrsMediaReviewType_FreeTextReview_CollectionPtr m_FreeTextReview;
    Mp7JrsRelatedMaterialPtr m_ReviewReference;
    bool m_ReviewReference_Exist; // For optional elements 
    Mp7JrsPtr< Mp7JrsNode > m_Reviewer;
    bool m_Reviewer_Exist; // For optional elements 

// no includefile for extension defined 
// file Mp7JrsMediaReviewType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1227MP7JRSMEDIAREVIEWTYPE_H

