/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1243MP7JRSMEDIATIMETYPE_H
#define _1243MP7JRSMEDIATIMETYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsMediaTimeTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// begin extension included
// file Mp7JrsMediaTimeType_ExtInclude.h

class Mp7JrsmediaTimePointType;
class Mp7JrsmediaDurationType;
#include "Mp7JrsmediaTimePointType.h"
// end extension included


class IMp7JrsmediaDurationType;
class IMp7JrsMediaIncrDurationType;
class IMp7JrsMediaRelIncrTimePointType;
class IMp7JrsMediaRelTimePointType;
class IMp7JrsmediaTimePointType;
class IMp7JrsMediaTimeType;
typedef Mp7JrsPtr< IMp7JrsmediaDurationType > Mp7JrsmediaDurationPtr;
typedef Mp7JrsPtr< IMp7JrsMediaIncrDurationType > Mp7JrsMediaIncrDurationPtr;
typedef Mp7JrsPtr< IMp7JrsMediaRelIncrTimePointType > Mp7JrsMediaRelIncrTimePointPtr;
typedef Mp7JrsPtr< IMp7JrsMediaRelTimePointType > Mp7JrsMediaRelTimePointPtr;
typedef Mp7JrsPtr< IMp7JrsmediaTimePointType > Mp7JrsmediaTimePointPtr;
typedef Mp7JrsPtr< IMp7JrsMediaTimeType> Mp7JrsMediaTimePtr;

/** 
 * Generated interface IMp7JrsMediaTimeType for class Mp7JrsMediaTimeType<br>
 * Located at: mds-2001.xsd, line 1010<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsMediaTimeType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsMediaTimeType();
    virtual ~IMp7JrsMediaTimeType();
        /** @name Sequence

         */
        //@{
        /** @name Choice

         */
        //@{
    /**
     * Get MediaTimePoint element.
     * @return Mp7JrsmediaTimePointPtr
     */
    virtual Mp7JrsmediaTimePointPtr GetMediaTimePoint() const = 0;

    /**
     * Set MediaTimePoint element.
     * @param item const Mp7JrsmediaTimePointPtr &
     */
    virtual void SetMediaTimePoint(const Mp7JrsmediaTimePointPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get MediaRelTimePoint element.
     * @return Mp7JrsMediaRelTimePointPtr
     */
    virtual Mp7JrsMediaRelTimePointPtr GetMediaRelTimePoint() const = 0;

    /**
     * Set MediaRelTimePoint element.
     * @param item const Mp7JrsMediaRelTimePointPtr &
     */
    virtual void SetMediaRelTimePoint(const Mp7JrsMediaRelTimePointPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get MediaRelIncrTimePoint element.
     * @return Mp7JrsMediaRelIncrTimePointPtr
     */
    virtual Mp7JrsMediaRelIncrTimePointPtr GetMediaRelIncrTimePoint() const = 0;

    /**
     * Set MediaRelIncrTimePoint element.
     * @param item const Mp7JrsMediaRelIncrTimePointPtr &
     */
    virtual void SetMediaRelIncrTimePoint(const Mp7JrsMediaRelIncrTimePointPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
        /** @name Choice

         */
        //@{
    /**
     * Get MediaDuration element.
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GetMediaDuration() const = 0;

    /**
     * Set MediaDuration element.
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SetMediaDuration(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get MediaIncrDuration element.
     * @return Mp7JrsMediaIncrDurationPtr
     */
    virtual Mp7JrsMediaIncrDurationPtr GetMediaIncrDuration() const = 0;

    /**
     * Set MediaIncrDuration element.
     * @param item const Mp7JrsMediaIncrDurationPtr &
     */
    virtual void SetMediaIncrDuration(const Mp7JrsMediaIncrDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
        //@}
// begin extension included
// file Mp7JrsMediaTimeType_ExtMethodDef.h


public:

	/** Get the begin time.
	  * @return Pointer to begin time.
	  */
	virtual Mp7JrsmediaTimePointPtr GetBeginTime();

	/** Set begin time.
	  *	@param beginTime Begin time to be set (will be copied).
	  */
	virtual void SetBeginTime(const Mp7JrsmediaTimePointPtr &beginTime, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/** Get the end time.
	  * @return Pointer to end time.
	  */
	virtual Mp7JrsmediaTimePointPtr GetEndTime();

	/** Set end time.
	  *	@param endTime End time to be set (will be copied).
	  */
	virtual void SetEndTime(const Mp7JrsmediaTimePointPtr &endTime, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT); 

	/** Get begin and end time. 
	  * beginTime and endTime contain the time points after return.
	  */
	virtual void GetTime(Mp7JrsmediaTimePointPtr& beginTime, Mp7JrsmediaTimePointPtr& endTime);

	/** Set begin and end time. The time points will be copied. */
	virtual void SetTime(const Mp7JrsmediaTimePointPtr &beginTime, const Mp7JrsmediaTimePointPtr &endTime, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/** Checks whether the given time point is within the media time. */
	virtual bool IsInside(const Mp7JrsmediaTimePointPtr &timePoint);
// end extension included


// begin extension included
// file Mp7JrsMediaTimeType_ExtPropDef.h
private:
	Mp7JrsmediaTimePointPtr  _endTime;   // end time
// end extension included

};




/*
 * Generated class Mp7JrsMediaTimeType<br>
 * Located at: mds-2001.xsd, line 1010<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 1010.<br>
 */
class MP7JRS_EXPORT Mp7JrsMediaTimeType :
        public IMp7JrsMediaTimeType
{
    friend class Mp7JrsMediaTimeTypeFactory; // constructs objects

public:
        /* @name Sequence

         */
        //@{
        /* @name Choice

         */
        //@{
    /*
     * Get MediaTimePoint element.
     * @return Mp7JrsmediaTimePointPtr
     */
    virtual Mp7JrsmediaTimePointPtr GetMediaTimePoint() const;

    /*
     * Set MediaTimePoint element.
     * @param item const Mp7JrsmediaTimePointPtr &
     */
    virtual void SetMediaTimePoint(const Mp7JrsmediaTimePointPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get MediaRelTimePoint element.
     * @return Mp7JrsMediaRelTimePointPtr
     */
    virtual Mp7JrsMediaRelTimePointPtr GetMediaRelTimePoint() const;

    /*
     * Set MediaRelTimePoint element.
     * @param item const Mp7JrsMediaRelTimePointPtr &
     */
    virtual void SetMediaRelTimePoint(const Mp7JrsMediaRelTimePointPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get MediaRelIncrTimePoint element.
     * @return Mp7JrsMediaRelIncrTimePointPtr
     */
    virtual Mp7JrsMediaRelIncrTimePointPtr GetMediaRelIncrTimePoint() const;

    /*
     * Set MediaRelIncrTimePoint element.
     * @param item const Mp7JrsMediaRelIncrTimePointPtr &
     */
    virtual void SetMediaRelIncrTimePoint(const Mp7JrsMediaRelIncrTimePointPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
        /* @name Choice

         */
        //@{
    /*
     * Get MediaDuration element.
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GetMediaDuration() const;

    /*
     * Set MediaDuration element.
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SetMediaDuration(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get MediaIncrDuration element.
     * @return Mp7JrsMediaIncrDurationPtr
     */
    virtual Mp7JrsMediaIncrDurationPtr GetMediaIncrDuration() const;

    /*
     * Set MediaIncrDuration element.
     * @param item const Mp7JrsMediaIncrDurationPtr &
     */
    virtual void SetMediaIncrDuration(const Mp7JrsMediaIncrDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsMediaTimeType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsMediaTimeType();

protected:
    Mp7JrsMediaTimeType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:


// DefinionChoice
    Mp7JrsmediaTimePointPtr m_MediaTimePoint;
    Mp7JrsMediaRelTimePointPtr m_MediaRelTimePoint;
    Mp7JrsMediaRelIncrTimePointPtr m_MediaRelIncrTimePoint;
// End DefinionChoice
// DefinionChoice
    Mp7JrsmediaDurationPtr m_MediaDuration;
    Mp7JrsMediaIncrDurationPtr m_MediaIncrDuration;
// End DefinionChoice

// no includefile for extension defined 
// file Mp7JrsMediaTimeType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1243MP7JRSMEDIATIMETYPE_H

