/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1277MP7JRSMETERTYPE_H
#define _1277MP7JRSMETERTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsMeterTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsMeterType_ExtInclude.h


#include "Mp7JrsAudioDType.h"
#include "Mp7JrsDType.h"
#include "Mp7JrsMeterType_Denominator_LocalType.h"
#include "Mp7JrsMpeg7BaseType.h"
class IMp7JrsAudioDType;
class IMp7JrsMeterType;
class IMp7JrsMeterType_Numerator_LocalType;
typedef Mp7JrsPtr< IMp7JrsAudioDType > Mp7JrsAudioDPtr;
typedef Mp7JrsPtr< IMp7JrsMeterType_Numerator_LocalType > Mp7JrsMeterType_Numerator_LocalPtr;
typedef Mp7JrsPtr< IMp7JrsMeterType> Mp7JrsMeterPtr;

/** 
 * Generated interface IMp7JrsMeterType for class Mp7JrsMeterType<br>
 * Located at: audio-2001.xsd, line 748<br>
 * Classified: Class<br>
 * Derived from: AudioDType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsMeterType 
 :
        public IMp7JrsAudioDType
{
public:
    // TODO: make these protected?
    IMp7JrsMeterType();
    virtual ~IMp7JrsMeterType();
        /** @name Sequence

         */
        //@{
    /**
     * Get Numerator element.
     * @return Mp7JrsMeterType_Numerator_LocalPtr
     */
    virtual Mp7JrsMeterType_Numerator_LocalPtr GetNumerator() const = 0;

    /**
     * Set Numerator element.
     * @param item const Mp7JrsMeterType_Numerator_LocalPtr &
     */
    virtual void SetNumerator(const Mp7JrsMeterType_Numerator_LocalPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get Denominator element.
     * @return Mp7JrsMeterType_Denominator_LocalType::Enumeration
     */
    virtual Mp7JrsMeterType_Denominator_LocalType::Enumeration GetDenominator() const = 0;

    /**
     * Set Denominator element.
     * @param item Mp7JrsMeterType_Denominator_LocalType::Enumeration
     */
    virtual void SetDenominator(Mp7JrsMeterType_Denominator_LocalType::Enumeration item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsMeterType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsMeterType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsMeterType<br>
 * Located at: audio-2001.xsd, line 748<br>
 * Classified: Class<br>
 * Derived from: AudioDType (Class)<br>
 * Defined in audio-2001.xsd, line 748.<br>
 */
class MP7JRS_EXPORT Mp7JrsMeterType :
        public IMp7JrsMeterType
{
    friend class Mp7JrsMeterTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsMeterType
     
     * @return Mp7JrsPtr< Mp7JrsAudioDType >
     */
    virtual Mp7JrsPtr< Mp7JrsAudioDType > GetBase() const;
        /* @name Sequence

         */
        //@{
    /*
     * Get Numerator element.
     * @return Mp7JrsMeterType_Numerator_LocalPtr
     */
    virtual Mp7JrsMeterType_Numerator_LocalPtr GetNumerator() const;

    /*
     * Set Numerator element.
     * @param item const Mp7JrsMeterType_Numerator_LocalPtr &
     */
    virtual void SetNumerator(const Mp7JrsMeterType_Numerator_LocalPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get Denominator element.
     * @return Mp7JrsMeterType_Denominator_LocalType::Enumeration
     */
    virtual Mp7JrsMeterType_Denominator_LocalType::Enumeration GetDenominator() const;

    /*
     * Set Denominator element.
     * @param item Mp7JrsMeterType_Denominator_LocalType::Enumeration
     */
    virtual void SetDenominator(Mp7JrsMeterType_Denominator_LocalType::Enumeration item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsMeterType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsMeterType();

protected:
    Mp7JrsMeterType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:

    // Base Class
    Mp7JrsPtr< Mp7JrsAudioDType > m_Base;

    Mp7JrsMeterType_Numerator_LocalPtr m_Numerator;
    Mp7JrsMeterType_Denominator_LocalType::Enumeration m_Denominator;

// no includefile for extension defined 
// file Mp7JrsMeterType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1277MP7JRSMETERTYPE_H

