/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1543MP7JRSPARTITIONTYPE_H
#define _1543MP7JRSPARTITIONTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsPartitionTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsPartitionType_ExtInclude.h


class IMp7JrsPartitionType;
class IMp7JrsPartitionType_dim_LocalType;
class IMp7JrsSignalPlaneOriginType;
class IMp7JrsSignalPlaneType;
typedef Mp7JrsPtr< IMp7JrsPartitionType_dim_LocalType > Mp7JrsPartitionType_dim_LocalPtr;
typedef Mp7JrsPtr< IMp7JrsPartitionType> Mp7JrsPartitionPtr;
typedef Mp7JrsPtr< IMp7JrsSignalPlaneOriginType > Mp7JrsSignalPlaneOriginPtr;
typedef Mp7JrsPtr< IMp7JrsSignalPlaneType > Mp7JrsSignalPlanePtr;

/** 
 * Generated interface IMp7JrsPartitionType for class Mp7JrsPartitionType<br>
 * Located at: mds-2001.xsd, line 4687<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsPartitionType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsPartitionType();
    virtual ~IMp7JrsPartitionType();
    /**
     * Get dim attribute.
     * @return Mp7JrsPartitionType_dim_LocalPtr
     */
    virtual Mp7JrsPartitionType_dim_LocalPtr Getdim() const = 0;

    /**
     * Get dim attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existdim() const = 0;

    /**
     * Set dim attribute.
     * @param item const Mp7JrsPartitionType_dim_LocalPtr &
     */
    virtual void Setdim(const Mp7JrsPartitionType_dim_LocalPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate dim attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatedim() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get Origin element.
     * @return Mp7JrsSignalPlaneOriginPtr
     */
    virtual Mp7JrsSignalPlaneOriginPtr GetOrigin() const = 0;

    virtual bool IsValidOrigin() const = 0;

    /**
     * Set Origin element.
     * @param item const Mp7JrsSignalPlaneOriginPtr &
     */
    virtual void SetOrigin(const Mp7JrsSignalPlaneOriginPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Origin element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateOrigin() = 0;

    /**
     * Get Start element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetStart() const = 0;

    /**
     * Set Start element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual void SetStart(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        /** @name Choice

         */
        //@{
    /**
     * Get End element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetEnd() const = 0;

    /**
     * Set End element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual void SetEnd(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get Extent element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetExtent() const = 0;

    /**
     * Set Extent element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual void SetExtent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
        //@}
// no includefile for extension defined 
// file Mp7JrsPartitionType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsPartitionType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsPartitionType<br>
 * Located at: mds-2001.xsd, line 4687<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 4687.<br>
 */
class MP7JRS_EXPORT Mp7JrsPartitionType :
        public IMp7JrsPartitionType
{
    friend class Mp7JrsPartitionTypeFactory; // constructs objects

public:
    /*
     * Get dim attribute.
     * @return Mp7JrsPartitionType_dim_LocalPtr
     */
    virtual Mp7JrsPartitionType_dim_LocalPtr Getdim() const;

    /*
     * Get dim attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existdim() const;

    /*
     * Set dim attribute.
     * @param item const Mp7JrsPartitionType_dim_LocalPtr &
     */
    virtual void Setdim(const Mp7JrsPartitionType_dim_LocalPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate dim attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatedim();

        /* @name Sequence

         */
        //@{
    /*
     * Get Origin element.
     * @return Mp7JrsSignalPlaneOriginPtr
     */
    virtual Mp7JrsSignalPlaneOriginPtr GetOrigin() const;

    virtual bool IsValidOrigin() const;

    /*
     * Set Origin element.
     * @param item const Mp7JrsSignalPlaneOriginPtr &
     */
    virtual void SetOrigin(const Mp7JrsSignalPlaneOriginPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Origin element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateOrigin();

    /*
     * Get Start element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetStart() const;

    /*
     * Set Start element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual void SetStart(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        /* @name Choice

         */
        //@{
    /*
     * Get End element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetEnd() const;

    /*
     * Set End element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual void SetEnd(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get Extent element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetExtent() const;

    /*
     * Set Extent element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsSignalPlaneFractionPtr</li>
     * <li>IMp7JrsSignalPlaneSamplePtr</li>
     * </ul>
     */
    virtual void SetExtent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsPartitionType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsPartitionType();

protected:
    Mp7JrsPartitionType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7JrsPartitionType_dim_LocalPtr m_dim;
    bool m_dim_Exist;


    Mp7JrsSignalPlaneOriginPtr m_Origin;
    bool m_Origin_Exist; // For optional elements 
    Mp7JrsPtr< Mp7JrsNode > m_Start;
// DefinionChoice
    Mp7JrsPtr< Mp7JrsNode > m_End;
    Mp7JrsPtr< Mp7JrsNode > m_Extent;
// End DefinionChoice

// no includefile for extension defined 
// file Mp7JrsPartitionType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1543MP7JRSPARTITIONTYPE_H

