/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1635MP7JRSPOSITIONTYPE_H
#define _1635MP7JRSPOSITIONTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsPositionTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsPositionType_ExtInclude.h


class IMp7JrsExtentType;
class IMp7JrsPositionType;
typedef Mp7JrsPtr< IMp7JrsExtentType > Mp7JrsExtentPtr;
typedef Mp7JrsPtr< IMp7JrsPositionType> Mp7JrsPositionPtr;

/** 
 * Generated interface IMp7JrsPositionType for class Mp7JrsPositionType<br>
 * Located at: mds-2001.xsd, line 4443<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsPositionType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsPositionType();
    virtual ~IMp7JrsPositionType();
    /**
     * Get origin attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Getorigin() const = 0;

    /**
     * Get origin attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existorigin() const = 0;

    /**
     * Set origin attribute.
     * @param item XMLCh *
     */
    virtual void Setorigin(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate origin attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateorigin() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get Displacement element.
     * @return Mp7JrsExtentPtr
     */
    virtual Mp7JrsExtentPtr GetDisplacement() const = 0;

    virtual bool IsValidDisplacement() const = 0;

    /**
     * Set Displacement element.
     * @param item const Mp7JrsExtentPtr &
     */
    virtual void SetDisplacement(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Displacement element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateDisplacement() = 0;

    /**
     * Get Direction element.
     * @return Mp7JrsExtentPtr
     */
    virtual Mp7JrsExtentPtr GetDirection() const = 0;

    virtual bool IsValidDirection() const = 0;

    /**
     * Set Direction element.
     * @param item const Mp7JrsExtentPtr &
     */
    virtual void SetDirection(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Direction element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateDirection() = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsPositionType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsPositionType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsPositionType<br>
 * Located at: mds-2001.xsd, line 4443<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 4443.<br>
 */
class MP7JRS_EXPORT Mp7JrsPositionType :
        public IMp7JrsPositionType
{
    friend class Mp7JrsPositionTypeFactory; // constructs objects

public:
    /*
     * Get origin attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Getorigin() const;

    /*
     * Get origin attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existorigin() const;

    /*
     * Set origin attribute.
     * @param item XMLCh *
     */
    virtual void Setorigin(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate origin attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateorigin();

        /* @name Sequence

         */
        //@{
    /*
     * Get Displacement element.
     * @return Mp7JrsExtentPtr
     */
    virtual Mp7JrsExtentPtr GetDisplacement() const;

    virtual bool IsValidDisplacement() const;

    /*
     * Set Displacement element.
     * @param item const Mp7JrsExtentPtr &
     */
    virtual void SetDisplacement(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Displacement element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateDisplacement();

    /*
     * Get Direction element.
     * @return Mp7JrsExtentPtr
     */
    virtual Mp7JrsExtentPtr GetDirection() const;

    virtual bool IsValidDirection() const;

    /*
     * Set Direction element.
     * @param item const Mp7JrsExtentPtr &
     */
    virtual void SetDirection(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Direction element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateDirection();

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsPositionType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsPositionType();

protected:
    Mp7JrsPositionType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    XMLCh * m_origin;
    bool m_origin_Exist;


    Mp7JrsExtentPtr m_Displacement;
    bool m_Displacement_Exist; // For optional elements 
    Mp7JrsExtentPtr m_Direction;
    bool m_Direction_Exist; // For optional elements 

// no includefile for extension defined 
// file Mp7JrsPositionType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1635MP7JRSPOSITIONTYPE_H

