/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _1695MP7JRSREFERENCETYPE_H
#define _1695MP7JRSREFERENCETYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsReferenceTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsReferenceType_ExtInclude.h


class IMp7JrsReferenceType;
class IMp7JrsxPathRefType;
typedef Mp7JrsPtr< IMp7JrsReferenceType> Mp7JrsReferencePtr;
typedef Mp7JrsPtr< IMp7JrsxPathRefType > Mp7JrsxPathRefPtr;

/** 
 * Generated interface IMp7JrsReferenceType for class Mp7JrsReferenceType<br>
 * Located at: mds-2001.xsd, line 867<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsReferenceType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsReferenceType();
    virtual ~IMp7JrsReferenceType();
    /**
     * Get idref attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Getidref() const = 0;

    /**
     * Get idref attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existidref() const = 0;

    /**
     * Set idref attribute.
     * @param item XMLCh *
     */
    virtual void Setidref(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate idref attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateidref() = 0;

    /**
     * Get xpath attribute.
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr Getxpath() const = 0;

    /**
     * Get xpath attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existxpath() const = 0;

    /**
     * Set xpath attribute.
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void Setxpath(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate xpath attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatexpath() = 0;

    /**
     * Get href attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Gethref() const = 0;

    /**
     * Get href attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existhref() const = 0;

    /**
     * Set href attribute.
     * @param item XMLCh *
     */
    virtual void Sethref(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate href attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatehref() = 0;

// no includefile for extension defined 
// file Mp7JrsReferenceType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsReferenceType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsReferenceType<br>
 * Located at: mds-2001.xsd, line 867<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 867.<br>
 */
class MP7JRS_EXPORT Mp7JrsReferenceType :
        public IMp7JrsReferenceType
{
    friend class Mp7JrsReferenceTypeFactory; // constructs objects

public:
    /*
     * Get idref attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Getidref() const;

    /*
     * Get idref attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existidref() const;

    /*
     * Set idref attribute.
     * @param item XMLCh *
     */
    virtual void Setidref(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate idref attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateidref();

    /*
     * Get xpath attribute.
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr Getxpath() const;

    /*
     * Get xpath attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existxpath() const;

    /*
     * Set xpath attribute.
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void Setxpath(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate xpath attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatexpath();

    /*
     * Get href attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Gethref() const;

    /*
     * Get href attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existhref() const;

    /*
     * Set href attribute.
     * @param item XMLCh *
     */
    virtual void Sethref(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate href attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatehref();


    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsReferenceType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsReferenceType();

protected:
    Mp7JrsReferenceType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    XMLCh * m_idref;
    bool m_idref_Exist;
    Mp7JrsxPathRefPtr m_xpath;
    bool m_xpath_Exist;
    XMLCh * m_href;
    bool m_href_Exist;



// no includefile for extension defined 
// file Mp7JrsReferenceType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _1695MP7JRSREFERENCETYPE_H

