/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _2291MP7JRSTEXTANNOTATIONTYPE_H
#define _2291MP7JRSTEXTANNOTATIONTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsTextAnnotationTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsTextAnnotationType_ExtInclude.h


class IMp7JrsTextAnnotationType;
class IMp7JrsTextAnnotationType_CollectionType;
class IMp7JrszeroToOneType;
typedef Mp7JrsPtr< IMp7JrsTextAnnotationType_CollectionType > Mp7JrsTextAnnotationType_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsTextAnnotationType> Mp7JrsTextAnnotationPtr;
typedef Mp7JrsPtr< IMp7JrszeroToOneType > Mp7JrszeroToOnePtr;

/** 
 * Generated interface IMp7JrsTextAnnotationType for class Mp7JrsTextAnnotationType<br>
 * Located at: mds-2001.xsd, line 1180<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsTextAnnotationType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsTextAnnotationType();
    virtual ~IMp7JrsTextAnnotationType();
    /**
     * Get relevance attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr Getrelevance() const = 0;

    /**
     * Get relevance attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existrelevance() const = 0;

    /**
     * Set relevance attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void Setrelevance(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate relevance attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidaterelevance() = 0;

    /**
     * Get confidence attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr Getconfidence() const = 0;

    /**
     * Get confidence attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existconfidence() const = 0;

    /**
     * Set confidence attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void Setconfidence(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate confidence attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateconfidence() = 0;

    /**
     * Get lang attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Getlang() const = 0;

    /**
     * Get lang attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existlang() const = 0;

    /**
     * Set lang attribute.
     * @param item XMLCh *
     */
    virtual void Setlang(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate lang attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatelang() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get TextAnnotationType_LocalType element.
     * @return Mp7JrsTextAnnotationType_CollectionPtr
     */
    virtual Mp7JrsTextAnnotationType_CollectionPtr GetTextAnnotationType_LocalType() const = 0;

    /**
     * Set TextAnnotationType_LocalType element.
     * @param item const Mp7JrsTextAnnotationType_CollectionPtr &
     */
    virtual void SetTextAnnotationType_LocalType(const Mp7JrsTextAnnotationType_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsTextAnnotationType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsTextAnnotationType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsTextAnnotationType<br>
 * Located at: mds-2001.xsd, line 1180<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 1180.<br>
 */
class MP7JRS_EXPORT Mp7JrsTextAnnotationType :
        public IMp7JrsTextAnnotationType
{
    friend class Mp7JrsTextAnnotationTypeFactory; // constructs objects

public:
    /*
     * Get relevance attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr Getrelevance() const;

    /*
     * Get relevance attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existrelevance() const;

    /*
     * Set relevance attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void Setrelevance(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate relevance attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidaterelevance();

    /*
     * Get confidence attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr Getconfidence() const;

    /*
     * Get confidence attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existconfidence() const;

    /*
     * Set confidence attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void Setconfidence(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate confidence attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateconfidence();

    /*
     * Get lang attribute.
     * @return XMLCh *
     */
    virtual XMLCh * Getlang() const;

    /*
     * Get lang attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existlang() const;

    /*
     * Set lang attribute.
     * @param item XMLCh *
     */
    virtual void Setlang(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate lang attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatelang();

        /* @name Sequence

         */
        //@{
    /*
     * Get TextAnnotationType_LocalType element.
     * @return Mp7JrsTextAnnotationType_CollectionPtr
     */
    virtual Mp7JrsTextAnnotationType_CollectionPtr GetTextAnnotationType_LocalType() const;

    /*
     * Set TextAnnotationType_LocalType element.
     * @param item const Mp7JrsTextAnnotationType_CollectionPtr &
     */
    virtual void SetTextAnnotationType_LocalType(const Mp7JrsTextAnnotationType_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsTextAnnotationType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsTextAnnotationType();

protected:
    Mp7JrsTextAnnotationType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7JrszeroToOnePtr m_relevance;
    bool m_relevance_Exist;
    Mp7JrszeroToOnePtr m_confidence;
    bool m_confidence_Exist;
    XMLCh * m_lang;
    bool m_lang_Exist;


    Mp7JrsTextAnnotationType_CollectionPtr m_TextAnnotationType_LocalType;

// no includefile for extension defined 
// file Mp7JrsTextAnnotationType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _2291MP7JRSTEXTANNOTATIONTYPE_H

