/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _2329MP7JRSTITLEMEDIATYPE_H
#define _2329MP7JRSTITLEMEDIATYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsTitleMediaTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsTitleMediaType_ExtInclude.h


class IMp7JrsImageLocatorType;
class IMp7JrsTemporalSegmentLocatorType;
class IMp7JrsTitleMediaType;
typedef Mp7JrsPtr< IMp7JrsImageLocatorType > Mp7JrsImageLocatorPtr;
typedef Mp7JrsPtr< IMp7JrsTemporalSegmentLocatorType > Mp7JrsTemporalSegmentLocatorPtr;
typedef Mp7JrsPtr< IMp7JrsTitleMediaType> Mp7JrsTitleMediaPtr;

/** 
 * Generated interface IMp7JrsTitleMediaType for class Mp7JrsTitleMediaType<br>
 * Located at: mds-2001.xsd, line 2555<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsTitleMediaType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsTitleMediaType();
    virtual ~IMp7JrsTitleMediaType();
        /** @name Sequence

         */
        //@{
    /**
     * Get TitleImage element.
     * @return Mp7JrsImageLocatorPtr
     */
    virtual Mp7JrsImageLocatorPtr GetTitleImage() const = 0;

    virtual bool IsValidTitleImage() const = 0;

    /**
     * Set TitleImage element.
     * @param item const Mp7JrsImageLocatorPtr &
     */
    virtual void SetTitleImage(const Mp7JrsImageLocatorPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate TitleImage element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateTitleImage() = 0;

    /**
     * Get TitleVideo element.
     * @return Mp7JrsTemporalSegmentLocatorPtr
     */
    virtual Mp7JrsTemporalSegmentLocatorPtr GetTitleVideo() const = 0;

    virtual bool IsValidTitleVideo() const = 0;

    /**
     * Set TitleVideo element.
     * @param item const Mp7JrsTemporalSegmentLocatorPtr &
     */
    virtual void SetTitleVideo(const Mp7JrsTemporalSegmentLocatorPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate TitleVideo element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateTitleVideo() = 0;

    /**
     * Get TitleAudio element.
     * @return Mp7JrsTemporalSegmentLocatorPtr
     */
    virtual Mp7JrsTemporalSegmentLocatorPtr GetTitleAudio() const = 0;

    virtual bool IsValidTitleAudio() const = 0;

    /**
     * Set TitleAudio element.
     * @param item const Mp7JrsTemporalSegmentLocatorPtr &
     */
    virtual void SetTitleAudio(const Mp7JrsTemporalSegmentLocatorPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate TitleAudio element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateTitleAudio() = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsTitleMediaType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsTitleMediaType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsTitleMediaType<br>
 * Located at: mds-2001.xsd, line 2555<br>
 * Classified: Class<br>
 * Defined in mds-2001.xsd, line 2555.<br>
 */
class MP7JRS_EXPORT Mp7JrsTitleMediaType :
        public IMp7JrsTitleMediaType
{
    friend class Mp7JrsTitleMediaTypeFactory; // constructs objects

public:
        /* @name Sequence

         */
        //@{
    /*
     * Get TitleImage element.
     * @return Mp7JrsImageLocatorPtr
     */
    virtual Mp7JrsImageLocatorPtr GetTitleImage() const;

    virtual bool IsValidTitleImage() const;

    /*
     * Set TitleImage element.
     * @param item const Mp7JrsImageLocatorPtr &
     */
    virtual void SetTitleImage(const Mp7JrsImageLocatorPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate TitleImage element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateTitleImage();

    /*
     * Get TitleVideo element.
     * @return Mp7JrsTemporalSegmentLocatorPtr
     */
    virtual Mp7JrsTemporalSegmentLocatorPtr GetTitleVideo() const;

    virtual bool IsValidTitleVideo() const;

    /*
     * Set TitleVideo element.
     * @param item const Mp7JrsTemporalSegmentLocatorPtr &
     */
    virtual void SetTitleVideo(const Mp7JrsTemporalSegmentLocatorPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate TitleVideo element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateTitleVideo();

    /*
     * Get TitleAudio element.
     * @return Mp7JrsTemporalSegmentLocatorPtr
     */
    virtual Mp7JrsTemporalSegmentLocatorPtr GetTitleAudio() const;

    virtual bool IsValidTitleAudio() const;

    /*
     * Set TitleAudio element.
     * @param item const Mp7JrsTemporalSegmentLocatorPtr &
     */
    virtual void SetTitleAudio(const Mp7JrsTemporalSegmentLocatorPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate TitleAudio element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateTitleAudio();

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsTitleMediaType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsTitleMediaType();

protected:
    Mp7JrsTitleMediaType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:


    Mp7JrsImageLocatorPtr m_TitleImage;
    bool m_TitleImage_Exist; // For optional elements 
    Mp7JrsTemporalSegmentLocatorPtr m_TitleVideo;
    bool m_TitleVideo_Exist; // For optional elements 
    Mp7JrsTemporalSegmentLocatorPtr m_TitleAudio;
    bool m_TitleAudio_Exist; // For optional elements 

// no includefile for extension defined 
// file Mp7JrsTitleMediaType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _2329MP7JRSTITLEMEDIATYPE_H

