/*****************************************************************************/
/* Copyright (C) 2003-2005, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/* This software may only be used under the terms of the JRS MPEG-7 Library  */
/* license, available at                                                     */
/* http://iis.joanneum.at/MPEG-7/JRS-MPEG-7-Lib-License.pdf                  */
/*****************************************************************************/

// ClassType_H.template
#ifndef _2467MP7JRSVARIATIONTYPE_H
#define _2467MP7JRSVARIATIONTYPE_H

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsVariationTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>


// no includefile for extension defined 
// file Mp7JrsVariationType_ExtInclude.h


#include "Mp7JrsDSType.h"
#include "Mp7JrsMpeg7BaseType.h"
class IMp7JrsDSType;
class IMp7JrsDSType_Header_CollectionType;
class IMp7JrsdurationType;
class IMp7JrsmediaDurationType;
class IMp7JrsMultimediaContentType;
class IMp7JrsVariationType;
class IMp7JrsVariationType_VariationRelationship_CollectionType;
class IMp7JrsxPathRefType;
class IMp7JrszeroToOneType;
typedef Mp7JrsPtr< IMp7JrsDSType > Mp7JrsDSPtr;
typedef Mp7JrsPtr< IMp7JrsDSType_Header_CollectionType > Mp7JrsDSType_Header_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsdurationType > Mp7JrsdurationPtr;
typedef Mp7JrsPtr< IMp7JrsmediaDurationType > Mp7JrsmediaDurationPtr;
typedef Mp7JrsPtr< IMp7JrsMultimediaContentType > Mp7JrsMultimediaContentPtr;
typedef Mp7JrsPtr< IMp7JrsVariationType_VariationRelationship_CollectionType > Mp7JrsVariationType_VariationRelationship_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsVariationType> Mp7JrsVariationPtr;
typedef Mp7JrsPtr< IMp7JrsxPathRefType > Mp7JrsxPathRefPtr;
typedef Mp7JrsPtr< IMp7JrszeroToOneType > Mp7JrszeroToOnePtr;

/** 
 * Generated interface IMp7JrsVariationType for class Mp7JrsVariationType<br>
 * Located at: mds-2001.xsd, line 5158<br>
 * Classified: Class<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsVariationType 
 :
        public IMp7JrsDSType
{
public:
    // TODO: make these protected?
    IMp7JrsVariationType();
    virtual ~IMp7JrsVariationType();
    /**
     * Get fidelity attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr Getfidelity() const = 0;

    /**
     * Get fidelity attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existfidelity() const = 0;

    /**
     * Set fidelity attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void Setfidelity(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate fidelity attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatefidelity() = 0;

    /**
     * Get priority attribute.
     * @return unsigned
     */
    virtual unsigned Getpriority() const = 0;

    /**
     * Get priority attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existpriority() const = 0;

    /**
     * Set priority attribute.
     * @param item unsigned
     */
    virtual void Setpriority(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate priority attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatepriority() = 0;

    /**
     * Get timeOffset attribute.
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GettimeOffset() const = 0;

    /**
     * Get timeOffset attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeOffset() const = 0;

    /**
     * Set timeOffset attribute.
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SettimeOffset(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate timeOffset attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeOffset() = 0;

    /**
     * Get timeScale attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr GettimeScale() const = 0;

    /**
     * Get timeScale attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeScale() const = 0;

    /**
     * Set timeScale attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void SettimeScale(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate timeScale attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeScale() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get Source element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetSource() const = 0;

    virtual bool IsValidSource() const = 0;

    /**
     * Set Source element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual void SetSource(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate Source element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateSource() = 0;

    /**
     * Get Content element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetContent() const = 0;

    /**
     * Set Content element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual void SetContent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

    /**
     * Get VariationRelationship element.
     * @return Mp7JrsVariationType_VariationRelationship_CollectionPtr
     */
    virtual Mp7JrsVariationType_VariationRelationship_CollectionPtr GetVariationRelationship() const = 0;

    /**
     * Set VariationRelationship element.
     * @param item const Mp7JrsVariationType_VariationRelationship_CollectionPtr &
     */
    virtual void SetVariationRelationship(const Mp7JrsVariationType_VariationRelationship_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
    /**
     * Get id attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return XMLCh *
     */
    virtual XMLCh * Getid() const = 0;

    /**
     * Get id attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existid() const = 0;

    /**
     * Set id attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item XMLCh *
     */
    virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate id attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateid() = 0;

    /**
     * Get timeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr GettimeBase() const = 0;

    /**
     * Get timeBase attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeBase() const = 0;

    /**
     * Set timeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void SettimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate timeBase attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeBase() = 0;

    /**
     * Get timeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsdurationPtr
     */
    virtual Mp7JrsdurationPtr GettimeUnit() const = 0;

    /**
     * Get timeUnit attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeUnit() const = 0;

    /**
     * Set timeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsdurationPtr &
     */
    virtual void SettimeUnit(const Mp7JrsdurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate timeUnit attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeUnit() = 0;

    /**
     * Get mediaTimeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const = 0;

    /**
     * Get mediaTimeBase attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeBase() const = 0;

    /**
     * Set mediaTimeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate mediaTimeBase attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeBase() = 0;

    /**
     * Get mediaTimeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const = 0;

    /**
     * Get mediaTimeUnit attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeUnit() const = 0;

    /**
     * Set mediaTimeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate mediaTimeUnit attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeUnit() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get Header element.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsDSType_Header_CollectionPtr
     */
    virtual Mp7JrsDSType_Header_CollectionPtr GetHeader() const = 0;

    /**
     * Set Header element.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsDSType_Header_CollectionPtr &
     */
    virtual void SetHeader(const Mp7JrsDSType_Header_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
// no includefile for extension defined 
// file Mp7JrsVariationType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsVariationType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsVariationType<br>
 * Located at: mds-2001.xsd, line 5158<br>
 * Classified: Class<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Derived from: DSType (Class)<br>
 * Defined in mds-2001.xsd, line 5158.<br>
 */
class MP7JRS_EXPORT Mp7JrsVariationType :
        public IMp7JrsVariationType
{
    friend class Mp7JrsVariationTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsVariationType
     
     * @return Mp7JrsPtr< Mp7JrsDSType >
     */
    virtual Mp7JrsPtr< Mp7JrsDSType > GetBase() const;
    /*
     * Get fidelity attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr Getfidelity() const;

    /*
     * Get fidelity attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existfidelity() const;

    /*
     * Set fidelity attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void Setfidelity(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate fidelity attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatefidelity();

    /*
     * Get priority attribute.
     * @return unsigned
     */
    virtual unsigned Getpriority() const;

    /*
     * Get priority attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existpriority() const;

    /*
     * Set priority attribute.
     * @param item unsigned
     */
    virtual void Setpriority(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate priority attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidatepriority();

    /*
     * Get timeOffset attribute.
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GettimeOffset() const;

    /*
     * Get timeOffset attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeOffset() const;

    /*
     * Set timeOffset attribute.
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SettimeOffset(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate timeOffset attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeOffset();

    /*
     * Get timeScale attribute.
     * @return Mp7JrszeroToOnePtr
     */
    virtual Mp7JrszeroToOnePtr GettimeScale() const;

    /*
     * Get timeScale attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeScale() const;

    /*
     * Set timeScale attribute.
     * @param item const Mp7JrszeroToOnePtr &
     */
    virtual void SettimeScale(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate timeScale attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeScale();

        /* @name Sequence

         */
        //@{
    /*
     * Get Source element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetSource() const;

    virtual bool IsValidSource() const;

    /*
     * Set Source element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual void SetSource(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate Source element.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidateSource();

    /*
     * Get Content element.
     * @return Mp7JrsPtr< Mp7JrsNode >
     * Possible types (within this library):
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual Mp7JrsPtr< Mp7JrsNode > GetContent() const;

    /*
     * Set Content element.
     * @param item const Mp7JrsPtr< Mp7JrsNode > &
     * Valid types for item:
     * <ul>
     * <li>IMp7JrsAnalyticEditedVideoPtr</li>
     * <li>IMp7JrsAudioPtr</li>
     * <li>IMp7JrsAudioVisualPtr</li>
     * <li>IMp7JrsImagePtr</li>
     * <li>IMp7JrsInkContentPtr</li>
     * <li>IMp7JrsMultimediaCollectionPtr</li>
     * <li>IMp7JrsMultimediaPtr</li>
     * <li>IMp7JrsSignalPtr</li>
     * <li>IMp7JrsVideoPtr</li>
     * </ul>
     */
    virtual void SetContent(const Mp7JrsPtr< Mp7JrsNode > & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

    /*
     * Get VariationRelationship element.
     * @return Mp7JrsVariationType_VariationRelationship_CollectionPtr
     */
    virtual Mp7JrsVariationType_VariationRelationship_CollectionPtr GetVariationRelationship() const;

    /*
     * Set VariationRelationship element.
     * @param item const Mp7JrsVariationType_VariationRelationship_CollectionPtr &
     */
    virtual void SetVariationRelationship(const Mp7JrsVariationType_VariationRelationship_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
    /*
     * Get id attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return XMLCh *
     */
    virtual XMLCh * Getid() const;

    /*
     * Get id attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existid() const;

    /*
     * Set id attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item XMLCh *
     */
    virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate id attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateid();

    /*
     * Get timeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr GettimeBase() const;

    /*
     * Get timeBase attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeBase() const;

    /*
     * Set timeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void SettimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate timeBase attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeBase();

    /*
     * Get timeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsdurationPtr
     */
    virtual Mp7JrsdurationPtr GettimeUnit() const;

    /*
     * Get timeUnit attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExisttimeUnit() const;

    /*
     * Set timeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsdurationPtr &
     */
    virtual void SettimeUnit(const Mp7JrsdurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate timeUnit attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatetimeUnit();

    /*
     * Get mediaTimeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const;

    /*
     * Get mediaTimeBase attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeBase() const;

    /*
     * Set mediaTimeBase attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate mediaTimeBase attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeBase();

    /*
     * Get mediaTimeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const;

    /*
     * Get mediaTimeUnit attribute validity information.
     * (Inherited from Mp7JrsDSType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeUnit() const;

    /*
     * Set mediaTimeUnit attribute.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate mediaTimeUnit attribute.
     * (Inherited from Mp7JrsDSType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeUnit();

        /* @name Sequence

         */
        //@{
    /*
     * Get Header element.
<br>
     * (Inherited from Mp7JrsDSType)
     * @return Mp7JrsDSType_Header_CollectionPtr
     */
    virtual Mp7JrsDSType_Header_CollectionPtr GetHeader() const;

    /*
     * Set Header element.
<br>
     * (Inherited from Mp7JrsDSType)
     * @param item const Mp7JrsDSType_Header_CollectionPtr &
     */
    virtual void SetHeader(const Mp7JrsDSType_Header_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const type, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsVariationType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsVariationType();

protected:
    Mp7JrsVariationType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7JrszeroToOnePtr m_fidelity;
    bool m_fidelity_Exist;
    unsigned m_priority;
    bool m_priority_Exist;
    Mp7JrsmediaDurationPtr m_timeOffset;
    bool m_timeOffset_Exist;
    Mp7JrszeroToOnePtr m_timeScale;
    bool m_timeScale_Exist;

    // Base Class
    Mp7JrsPtr< Mp7JrsDSType > m_Base;

    Mp7JrsPtr< Mp7JrsNode > m_Source;
    bool m_Source_Exist; // For optional elements 
    Mp7JrsPtr< Mp7JrsNode > m_Content;
    Mp7JrsVariationType_VariationRelationship_CollectionPtr m_VariationRelationship;

// no includefile for extension defined 
// file Mp7JrsVariationType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();

};

#endif // _2467MP7JRSVARIATIONTYPE_H

